from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class WithTaskIdClosePostRequestBody(Parsable):
    # A list of attachment IDs to duplicate from a submittal item's previous stage in the workflow. To retrieve available attachments, call `GET items/:itemId/attachments </en/docs/acc/v1/reference/http/submittals-items-itemId-attachments-GET/>`_.
    duplicate_attachments: Optional[list[str]] = None
    # The body of the response comment, containing feedback or instructions related to the task.
    response_comment: Optional[str] = None
    # The ID of the response associated with the task, linking to the specific feedback or action taken. To retrieve this ID, call `GET responses </en/docs/acc/v1/reference/http/submittals-responses-GET/>`_.
    response_id: Optional[str] = None
    # Not relevant
    save_attachment_drafts: Optional[list[str]] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> WithTaskIdClosePostRequestBody:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: WithTaskIdClosePostRequestBody
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return WithTaskIdClosePostRequestBody()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "duplicateAttachments": lambda n : setattr(self, 'duplicate_attachments', n.get_collection_of_primitive_values(str)),
            "responseComment": lambda n : setattr(self, 'response_comment', n.get_str_value()),
            "responseId": lambda n : setattr(self, 'response_id', n.get_str_value()),
            "saveAttachmentDrafts": lambda n : setattr(self, 'save_attachment_drafts', n.get_collection_of_primitive_values(str)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_collection_of_primitive_values("duplicateAttachments", self.duplicate_attachments)
        writer.write_str_value("responseComment", self.response_comment)
        writer.write_str_value("responseId", self.response_id)
        writer.write_collection_of_primitive_values("saveAttachmentDrafts", self.save_attachment_drafts)
    

