from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .rfis_post_response_architects_type import RfisPostResponse_architects_type

@dataclass
class RfisPostResponse_architects(Parsable):
    # The Autodesk ID of the architect.To find details about the user, call `GET users </en/docs/acc/v1/reference/http/admin-projectsprojectId-users-GET>`_.
    id: Optional[str] = None
    # The type of architect. Will always be ``user``.
    type: Optional[RfisPostResponse_architects_type] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> RfisPostResponse_architects:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: RfisPostResponse_architects
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return RfisPostResponse_architects()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .rfis_post_response_architects_type import RfisPostResponse_architects_type

        from .rfis_post_response_architects_type import RfisPostResponse_architects_type

        fields: dict[str, Callable[[Any], None]] = {
            "id": lambda n : setattr(self, 'id', n.get_str_value()),
            "type": lambda n : setattr(self, 'type', n.get_enum_value(RfisPostResponse_architects_type)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("id", self.id)
        writer.write_enum_value("type", self.type)
    

