from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from .folders_get_response import FoldersGetResponse
    from .get_sort_query_parameter_type import GetSortQueryParameterType

class FoldersRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /construction/transmittals/v1/projects/{projectId}/transmittals/{transmittalId}/folders
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new FoldersRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/construction/transmittals/v1/projects/{projectId}/transmittals/{transmittalId}/folders{?limit*,offset*,sort*}", path_parameters)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[FoldersRequestBuilderGetQueryParameters]] = None) -> Optional[FoldersGetResponse]:
        """
        Retrieves all folders associated with the documents included in a specific transmittal.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[FoldersGetResponse]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .folders_get_response import FoldersGetResponse

        return await self.request_adapter.send_async(request_info, FoldersGetResponse, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[FoldersRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        Retrieves all folders associated with the documents included in a specific transmittal.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def with_url(self,raw_url: str) -> FoldersRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: FoldersRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return FoldersRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class FoldersRequestBuilderGetQueryParameters():
        """
        Retrieves all folders associated with the documents included in a specific transmittal.
        """
        # The maximum number of results to return per page.Acceptable values: 1-200.Default value: 20.For example, to limit the response to two results per page, use ``limit=2``.
        limit: Optional[int] = None

        # The index from which the response starts returning results.Default value: 0.For example, to skip the first three results, use ``offset=3``.
        offset: Optional[int] = None

        # Sorts the folders by a supported field and order.By default, folders are sorted in ascending order by ``name`` (``name asc``).To sort in descending order, add ``desc`` after the field name.Format: ``sort=<field> [asc or desc]``Supported fields: ``name``, ``lastUpdatedAt``, ``updatedByName``.Examples:- ``sort=name asc`` – sorts folders alphabetically by name.- ``sort=lastUpdatedAt desc`` – sorts folders by last updated time in descending order.Possible values: ``name``, ``lastUpdatedAt``, ``updatedByName``, ``name asc``, ``lastUpdatedAt asc``, ``updatedByName asc``, ``name desc``, ``lastUpdatedAt desc``, ``updatedByName desc``
        sort: Optional[GetSortQueryParameterType] = None

    
    @dataclass
    class FoldersRequestBuilderGetRequestConfiguration(RequestConfiguration[FoldersRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    

