from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class WorkflowsPostRequestBody_steps_candidates_users(Parsable):
    # The Autodesk ID of the user. To find the Autodesk IDs of users for a project, call `GET projects/users </en/docs/acc/v1/reference/http/admin-projectsprojectId-users-GET/>`_.
    autodesk_id: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> WorkflowsPostRequestBody_steps_candidates_users:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: WorkflowsPostRequestBody_steps_candidates_users
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return WorkflowsPostRequestBody_steps_candidates_users()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "autodeskId": lambda n : setattr(self, 'autodesk_id', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("autodeskId", self.autodesk_id)
    

