from enum import Enum

class VersionsBatchGetPostResponse_results_processState(str, Enum):
    NEEDS_PROCESSING = "NEEDS_PROCESSING",
    PROCESSING = "PROCESSING",
    PREVIOUS_SEED_PENDING = "PREVIOUS_SEED_PENDING",
    EXTRACTION_PENDING = "EXTRACTION_PENDING",
    SPLITTING = "SPLITTING",
    PREVIOUS_DOC_PENDING = "PREVIOUS_DOC_PENDING",
    PROCESSING_ABORTING = "PROCESSING_ABORTING",
    PROCESSING_ABORTED = "PROCESSING_ABORTED",
    PROCESSING_COMPLETE = "PROCESSING_COMPLETE",
    PROCESSING_PROMOTION = "PROCESSING_PROMOTION",
    PROCESSING_COPY = "PROCESSING_COPY",
    PROCESSING_PROMOTING = "PROCESSING_PROMOTING",
    PROCESSING_COPYING = "PROCESSING_COPYING",
    PROCESSING_SUSPEND = "PROCESSING_SUSPEND",

