from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from .attributes_get_response import AttributesGetResponse
    from .attributes_post_request_body import AttributesPostRequestBody
    from .attributes_post_response import AttributesPostResponse
    from .item.with_attribute_item_request_builder import WithAttributeItemRequestBuilder

class AttributesRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /construction/rfis/v3/projects/{projectId}/attributes
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new AttributesRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/construction/rfis/v3/projects/{projectId}/attributes{?filter%5Bstatus%5D*,limit*,offset*}", path_parameters)
    
    def by_attribute_id(self,attribute_id: str) -> WithAttributeItemRequestBuilder:
        """
        Gets an item from the Autodesk.ACC.construction.rfis.v3.projects.item.attributes.item collection
        param attribute_id: The ID of the custom attribute.
        Returns: WithAttributeItemRequestBuilder
        """
        if attribute_id is None:
            raise TypeError("attribute_id cannot be null.")
        from .item.with_attribute_item_request_builder import WithAttributeItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["attributeId"] = attribute_id
        return WithAttributeItemRequestBuilder(self.request_adapter, url_tpl_params)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[AttributesRequestBuilderGetQueryParameters]] = None) -> Optional[AttributesGetResponse]:
        """
        Retrieves all custom attribute definitions for a project.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[AttributesGetResponse]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .attributes_get_response import AttributesGetResponse

        return await self.request_adapter.send_async(request_info, AttributesGetResponse, None)
    
    async def post(self,body: AttributesPostRequestBody, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> Optional[AttributesPostResponse]:
        """
        Creates a custom attribute definition for a project.
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[AttributesPostResponse]
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = self.to_post_request_information(
            body, request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .attributes_post_response import AttributesPostResponse

        return await self.request_adapter.send_async(request_info, AttributesPostResponse, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[AttributesRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        Retrieves all custom attribute definitions for a project.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def to_post_request_information(self,body: AttributesPostRequestBody, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        Creates a custom attribute definition for a project.
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = RequestInformation(Method.POST, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        request_info.set_content_from_parsable(self.request_adapter, "application/json", body)
        return request_info
    
    def with_url(self,raw_url: str) -> AttributesRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: AttributesRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return AttributesRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class AttributesRequestBuilderGetQueryParameters():
        """
        Retrieves all custom attribute definitions for a project.
        """
        def get_query_parameter(self,original_name: str) -> str:
            """
            Maps the query parameters names to their encoded names for the URI template parsing.
            param original_name: The original query parameter name in the class.
            Returns: str
            """
            if original_name is None:
                raise TypeError("original_name cannot be null.")
            if original_name == "filterstatus":
                return "filter%5Bstatus%5D"
            if original_name == "limit":
                return "limit"
            if original_name == "offset":
                return "offset"
            return original_name
        
        # Filters the response to only include custom attributes with the specified status. Possible values: ``active``, ``inactive``, ``hidden``.
        filterstatus: Optional[list[str]] = None

        # The number of RFIs to return in the response. Acceptable values: ``1–200``. Default: ``10``. For example, to limit the response to two items per page, use ``limit=2``
        limit: Optional[int] = None

        # The number of items to skip before starting to return results.For example, to begin the results from the fourth item, use ``offset=3``.
        offset: Optional[int] = None

    
    @dataclass
    class AttributesRequestBuilderGetRequestConfiguration(RequestConfiguration[AttributesRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    
    @dataclass
    class AttributesRequestBuilderPostRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    

