from enum import Enum

class WithRfiPatchResponse_attachments_attachmentType(str, Enum):
    RfiResponse = "rfiResponse",
    RfiOfficialResponse = "rfiOfficialResponse",
    BridgeFiles = "bridgeFiles",
    RfiWebHiddenFiles = "rfiWebHiddenFiles",

