from enum import Enum

class GetFilterTypeQueryParameterType(str, Enum):
    Estimated = "estimated",
    Proposed = "proposed",
    Submitted = "submitted",
    Approved = "approved",
    Committed = "committed",

