from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .approval_statuses_get_response_results_approval_status import ApprovalStatusesGetResponse_results_approvalStatus
    from .approval_statuses_get_response_results_review import ApprovalStatusesGetResponse_results_review

@dataclass
class ApprovalStatusesGetResponse_results(Parsable):
    # The file’s approval status within a specific review.
    approval_status: Optional[ApprovalStatusesGetResponse_results_approvalStatus] = None
    # Metadata about the review in which this file version was included.
    review: Optional[ApprovalStatusesGetResponse_results_review] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ApprovalStatusesGetResponse_results:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ApprovalStatusesGetResponse_results
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ApprovalStatusesGetResponse_results()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .approval_statuses_get_response_results_approval_status import ApprovalStatusesGetResponse_results_approvalStatus
        from .approval_statuses_get_response_results_review import ApprovalStatusesGetResponse_results_review

        from .approval_statuses_get_response_results_approval_status import ApprovalStatusesGetResponse_results_approvalStatus
        from .approval_statuses_get_response_results_review import ApprovalStatusesGetResponse_results_review

        fields: dict[str, Callable[[Any], None]] = {
            "approvalStatus": lambda n : setattr(self, 'approval_status', n.get_object_value(ApprovalStatusesGetResponse_results_approvalStatus)),
            "review": lambda n : setattr(self, 'review', n.get_object_value(ApprovalStatusesGetResponse_results_review)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_object_value("approvalStatus", self.approval_status)
        writer.write_object_value("review", self.review)
    

