from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class RelationshipsSyncStatusPostResponse_results(Parsable):
    # If set to true, data is available for synchronization using the supplied synchronization token.
    more_data: Optional[bool] = None
    # If set to true, the data returned by the synchronization endpoint can be used to overwrite local copies.
    overwrite: Optional[bool] = None
    # An optional reference passed by the caller and returned by the service.
    reference_id: Optional[str] = None
    # The token that can be used to obtain data via the synchronization endpoint.
    sync_token: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> RelationshipsSyncStatusPostResponse_results:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: RelationshipsSyncStatusPostResponse_results
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return RelationshipsSyncStatusPostResponse_results()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "moreData": lambda n : setattr(self, 'more_data', n.get_bool_value()),
            "overwrite": lambda n : setattr(self, 'overwrite', n.get_bool_value()),
            "referenceId": lambda n : setattr(self, 'reference_id', n.get_str_value()),
            "syncToken": lambda n : setattr(self, 'sync_token', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_bool_value("moreData", self.more_data)
        writer.write_bool_value("overwrite", self.overwrite)
        writer.write_str_value("referenceId", self.reference_id)
        writer.write_str_value("syncToken", self.sync_token)
    

