from enum import Enum

class TransmittalsGetResponse_results_packedStatus(str, Enum):
    SUCCESS = "SUCCESS",
    PARTIAL_SUCCESS = "PARTIAL_SUCCESS",
    FAILED = "FAILED",
    PROCESSING = "PROCESSING",
    EXPIRED = "EXPIRED",
    NOT_ALLOWED = "NOT_ALLOWED",

