from enum import Enum

class SubmittalsSummaryGetResponse_submittalGroups_submittalGroup(str, Enum):
    ACTIONANDINFORMATIONAL = "ACTION AND INFORMATIONAL",
    CLOSEOUTSUBMITTALS = "CLOSEOUT SUBMITTALS",
    FIELDQUALITYCONTROL = "FIELD QUALITY CONTROL",
    Mockups = "Mockups",
    QUALITYASSURANCE = "QUALITY ASSURANCE",
    TestsAndInspections = "Tests And Inspections",
    DIVISION01REQUIREMENTS = "DIVISION 01 REQUIREMENTS",

