from enum import Enum

class FieldsGetResponse_type(str, Enum):
    Unknown = "Unknown",
    Boolean = "Boolean",
    Integer = "Integer",
    Double = "Double",
    Blob = "Blob",
    DbKey = "DbKey",
    String = "String",
    LocalizableString = "LocalizableString",
    DateTime = "DateTime",
    GeoLocation = "GeoLocation",
    Position = "Position",

