from enum import Enum

class GetAssociationTypeQueryParameterType(str, Enum):
    Contract = "Contract",
    MainContract = "MainContract",
    BudgetPayment = "BudgetPayment",
    CostPayment = "CostPayment",
    OCO = "OCO",
    SCO = "SCO",
    PCO = "PCO",
    RFQ = "RFQ",
    RCO = "RCO",

