from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .reviews_post_request_body_workflow_options_steps_candidates import ReviewsPostRequestBody_workflowOptions_steps_candidates

@dataclass
class ReviewsPostRequestBody_workflowOptions_steps(Parsable):
    # (Displayed in the UI when selecting Reviewers/Approvers for a step) Defines the users, roles, or companies to specify for this step of the approval workflow. At least one of the fields (``users``, ``roles``, or ``companies``) must be provided.
    candidates: Optional[ReviewsPostRequestBody_workflowOptions_steps_candidates] = None
    # The ID of the step in the approval workflow. Use this value to set the candidates for the step when creating the review. Retrieve step IDs by calling `GET workflows </en/docs/acc/v1/reference/http/reviews-workflows-GET/>`_.
    id: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ReviewsPostRequestBody_workflowOptions_steps:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ReviewsPostRequestBody_workflowOptions_steps
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ReviewsPostRequestBody_workflowOptions_steps()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .reviews_post_request_body_workflow_options_steps_candidates import ReviewsPostRequestBody_workflowOptions_steps_candidates

        from .reviews_post_request_body_workflow_options_steps_candidates import ReviewsPostRequestBody_workflowOptions_steps_candidates

        fields: dict[str, Callable[[Any], None]] = {
            "candidates": lambda n : setattr(self, 'candidates', n.get_object_value(ReviewsPostRequestBody_workflowOptions_steps_candidates)),
            "id": lambda n : setattr(self, 'id', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_object_value("candidates", self.candidates)
        writer.write_str_value("id", self.id)
    

