from enum import Enum

class ValuesBatchUpdatePutResponse_customValues_toggleVal(str, Enum):
    Yes = "Yes",
    No = "No",
    False_ = "False",
    True_ = "True",
    Minus = "Minus",
    Plus = "Plus",
    Fail = "Fail",
    Pass_ = "Pass",
    NA = "NA",

