from enum import Enum

class ActionsPostRequestBody_associationType(str, Enum):
    FormInstance = "FormInstance",
    OCO = "OCO",
    PCO = "PCO",
    RCO = "RCO",
    RFQ = "RFQ",
    SCO = "SCO",
    Expense = "Expense",
    Contract = "Contract",
    CostPayment = "CostPayment",
    BudgetPayment = "BudgetPayment",
    BudgetTransfer = "BudgetTransfer",
    MainContract = "MainContract",
    DistributionItem = "DistributionItem",

