from enum import Enum

class GetSortQueryParameterType(str, Enum):
    Asc = "asc",
    Desc = "desc",
    SortFieldNameDesc = "sort=fieldName [desc]",
    Name = "name",
    CreatedAt = "createdAt",
    UpdatedAt = "updatedAt",
    DisplayId = "displayId",
    SortName = "sort=name",
    SortCreatedAtDesc = "sort=createdAt desc",

