from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class ChangeOrderGetResponse_splitNumber(Parsable):
    """
    Not relevant
    """
    # Not relevant
    is_free_modify: Optional[bool] = None
    # Not relevant
    number: Optional[str] = None
    # Not relevant
    postfix: Optional[str] = None
    # Not relevant
    prefix: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ChangeOrderGetResponse_splitNumber:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ChangeOrderGetResponse_splitNumber
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ChangeOrderGetResponse_splitNumber()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "isFreeModify": lambda n : setattr(self, 'is_free_modify', n.get_bool_value()),
            "number": lambda n : setattr(self, 'number', n.get_str_value()),
            "postfix": lambda n : setattr(self, 'postfix', n.get_str_value()),
            "prefix": lambda n : setattr(self, 'prefix', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_bool_value("isFreeModify", self.is_free_modify)
        writer.write_str_value("number", self.number)
        writer.write_str_value("postfix", self.postfix)
        writer.write_str_value("prefix", self.prefix)
    

