from enum import Enum

class DocumentsGetResponse_associationType(str, Enum):
    Budget = "Budget",
    Contract = "Contract",
    ScheduleOfValue = "ScheduleOfValue",
    FormInstance = "FormInstance",
    CostItem = "CostItem",
    Payment = "Payment",
    MainContract = "MainContract",
    BudgetPayment = "BudgetPayment",
    Expense = "Expense",
    CostPayment = "CostPayment",
    ExpenseItem = "ExpenseItem",
    PaymentItem = "PaymentItem",
    OCO = "OCO",
    RCO = "RCO",
    SCO = "SCO",
    PCO = "PCO",
    RFQ = "RFQ",
    DistributionItem = "DistributionItem",
    BudgetTransfer = "BudgetTransfer",
    Fee = "Fee",

