from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .with_view_delete_response_job_seed import WithViewDeleteResponse_job_seed

@dataclass
class WithViewDeleteResponse_job(Parsable):
    """
    A job.
    """
    # The operation associated with the job.
    operation: Optional[str] = None
    # The JSON payload which seeded the job.
    seed: Optional[WithViewDeleteResponse_job_seed] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> WithViewDeleteResponse_job:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: WithViewDeleteResponse_job
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return WithViewDeleteResponse_job()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .with_view_delete_response_job_seed import WithViewDeleteResponse_job_seed

        from .with_view_delete_response_job_seed import WithViewDeleteResponse_job_seed

        fields: dict[str, Callable[[Any], None]] = {
            "operation": lambda n : setattr(self, 'operation', n.get_str_value()),
            "seed": lambda n : setattr(self, 'seed', n.get_object_value(WithViewDeleteResponse_job_seed)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("operation", self.operation)
        writer.write_object_value("seed", self.seed)
    

