from enum import Enum

class IssuesGetResponse_results_customAttributes_type(str, Enum):
    Numeric = "numeric",
    Paragraph = "paragraph",
    List_ = "list",
    Dropdown = "dropdown",
    Text = "text",

