from enum import Enum

class WithTakeoffTypeGetResponse_tool(str, Enum):
    COUNT = "COUNT",
    DISTANCE = "DISTANCE",
    AREA = "AREA",
    SELECT = "SELECT",
    LINEAR = "LINEAR",
    BIM = "BIM",

