from enum import Enum

class FormsPostResponse_customValues_valueName(str, Enum):
    TextVal = "textVal",
    ToggleVal = "toggleVal",
    ArrayVal = "arrayVal",
    NumberVal = "numberVal",
    ChoiceVal = "choiceVal",
    DateVal = "dateVal",
    SvgVal = "svgVal",

