from enum import Enum

class ClosedPostResponse_reason(str, Enum):
    OTHER = "OTHER",
    VALID_INTERFACE = "VALID_INTERFACE",
    VALID_PENETRATION = "VALID_PENETRATION",
    MINIMAL_OVERLAP = "MINIMAL_OVERLAP",
    ITEM_CAN_FLEX = "ITEM_CAN_FLEX",
    MODEL_INACCURACY = "MODEL_INACCURACY",
    FIELD_FIX = "FIELD_FIX",

