from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from .review_sheets.review_sheets_request_builder import ReviewSheetsRequestBuilder
    from .review_sheets_publish.review_sheets_publish_request_builder import ReviewSheetsPublishRequestBuilder
    from .thumbnails_batch_get.thumbnails_batch_get_request_builder import ThumbnailsBatchGetRequestBuilder
    from .with_upload_get_response import WithUploadGetResponse

class WithUploadItemRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /construction/sheets/v1/projects/{projectId}/uploads/{uploadId}
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new WithUploadItemRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/construction/sheets/v1/projects/{projectId}/uploads/{uploadId}", path_parameters)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> Optional[WithUploadGetResponse]:
        """
        Checks the processing status of a specific uploaded file.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[WithUploadGetResponse]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .with_upload_get_response import WithUploadGetResponse

        return await self.request_adapter.send_async(request_info, WithUploadGetResponse, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        Checks the processing status of a specific uploaded file.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def with_url(self,raw_url: str) -> WithUploadItemRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: WithUploadItemRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return WithUploadItemRequestBuilder(self.request_adapter, raw_url)
    
    @property
    def review_sheets(self) -> ReviewSheetsRequestBuilder:
        """
        The reviewSheets property
        """
        from .review_sheets.review_sheets_request_builder import ReviewSheetsRequestBuilder

        return ReviewSheetsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def review_sheets_publish(self) -> ReviewSheetsPublishRequestBuilder:
        """
        The reviewSheetsPublish property
        """
        from .review_sheets_publish.review_sheets_publish_request_builder import ReviewSheetsPublishRequestBuilder

        return ReviewSheetsPublishRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def thumbnails_batch_get(self) -> ThumbnailsBatchGetRequestBuilder:
        """
        The thumbnailsBatchGet property
        """
        from .thumbnails_batch_get.thumbnails_batch_get_request_builder import ThumbnailsBatchGetRequestBuilder

        return ThumbnailsBatchGetRequestBuilder(self.request_adapter, self.path_parameters)
    
    @dataclass
    class WithUploadItemRequestBuilderGetRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    

