from enum import Enum

class ClassificationSystemsGetResponse_results_type(str, Enum):
    CLASSIFICATION_SYSTEM_1 = "CLASSIFICATION_SYSTEM_1",
    CLASSIFICATION_SYSTEM_2 = "CLASSIFICATION_SYSTEM_2",

