from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class ItemsPostResponse_permittedActions_fields(Parsable):
    """
    A list of field names for which values must be provided when performing the action. An empty array indicates no specific set of values.
    """
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ItemsPostResponse_permittedActions_fields:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ItemsPostResponse_permittedActions_fields
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ItemsPostResponse_permittedActions_fields()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
    

