from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Optional, TYPE_CHECKING, Union
from uuid import UUID
from warnings import warn

if TYPE_CHECKING:
    from .item.with_segment_item_request_builder import WithSegmentItemRequestBuilder
    from .segments_get_response import SegmentsGetResponse
    from .segments_post_request_body import SegmentsPostRequestBody
    from .segments_post_response import SegmentsPostResponse

class SegmentsRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /cost/v1/containers/{containerId}/templates/{templateId}/segments
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new SegmentsRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/cost/v1/containers/{containerId}/templates/{templateId}/segments{?filter%5BlastModifiedSince%5D*,filter%5Bname%5D*,limit*,offset*,sort*}", path_parameters)
    
    def by_segment_id(self,segment_id: UUID) -> WithSegmentItemRequestBuilder:
        """
        Gets an item from the Autodesk.ACC.cost.v1.containers.item.templates.item.segments.item collection
        param segment_id: The segment ID. To obtain a segment ID, use `GET templates/:templateId/segments </en/docs/bim360/v1/reference/http/cost-segments-GET/>`_.
        Returns: WithSegmentItemRequestBuilder
        """
        if segment_id is None:
            raise TypeError("segment_id cannot be null.")
        from .item.with_segment_item_request_builder import WithSegmentItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["segmentId"] = segment_id
        return WithSegmentItemRequestBuilder(self.request_adapter, url_tpl_params)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[SegmentsRequestBuilderGetQueryParameters]] = None) -> Optional[SegmentsGetResponse]:
        """
        Retrieves all of the segments in a budget code template.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[SegmentsGetResponse]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .segments_get_response import SegmentsGetResponse

        return await self.request_adapter.send_async(request_info, SegmentsGetResponse, None)
    
    async def post(self,body: SegmentsPostRequestBody, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> Optional[SegmentsPostResponse]:
        """
        Creates a new segment in the budget code template.
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[SegmentsPostResponse]
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = self.to_post_request_information(
            body, request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .segments_post_response import SegmentsPostResponse

        return await self.request_adapter.send_async(request_info, SegmentsPostResponse, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[SegmentsRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        Retrieves all of the segments in a budget code template.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def to_post_request_information(self,body: SegmentsPostRequestBody, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        Creates a new segment in the budget code template.
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = RequestInformation(Method.POST, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        request_info.set_content_from_parsable(self.request_adapter, "application/json", body)
        return request_info
    
    def with_url(self,raw_url: str) -> SegmentsRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: SegmentsRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return SegmentsRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class SegmentsRequestBuilderGetQueryParameters():
        """
        Retrieves all of the segments in a budget code template.
        """
        def get_query_parameter(self,original_name: str) -> str:
            """
            Maps the query parameters names to their encoded names for the URI template parsing.
            param original_name: The original query parameter name in the class.
            Returns: str
            """
            if original_name is None:
                raise TypeError("original_name cannot be null.")
            if original_name == "filterlast_modified_since":
                return "filter%5BlastModifiedSince%5D"
            if original_name == "filtername":
                return "filter%5Bname%5D"
            if original_name == "limit":
                return "limit"
            if original_name == "offset":
                return "offset"
            if original_name == "sort":
                return "sort"
            return original_name
        
        # Returns only items that were modified since the specified date and time, in ISO 8601 format. For example, ``filter[lastModifiedSince]=2020-03-01T13:00:00Z``.
        filterlast_modified_since: Optional[str] = None

        # Returns only items with the specified name. For example, ``filter[name]=Labor``.Max length: 255
        filtername: Optional[str] = None

        # The maximum number of records returned per page. Default: ``100``. A page may contain fewer records than the limit if there are fewer matching items or if it is the last page of results.
        limit: Optional[int] = None

        # The number of records to skip before returning results. Used together with ``limit`` to paginate through results, where ``offset`` specifies the starting point and ``limit`` specifies the number of records to return.
        offset: Optional[int] = None

        # Defines the sort order for the results. Each attribute can be sorted in ``asc`` (default) or ``desc`` order. For example, ``sort=name desc`` sorts the results by name in descending order.
        sort: Optional[str] = None

    
    @dataclass
    class SegmentsRequestBuilderGetRequestConfiguration(RequestConfiguration[SegmentsRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    
    @dataclass
    class SegmentsRequestBuilderPostRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    

