from enum import Enum

class WithTransmittalGetResponse_status(str, Enum):
    SENDING = "SENDING",
    Recipients = "recipients",
    ExternalMembers = "externalMembers",
    COMPLETED = "COMPLETED",
    FAILED = "FAILED",

