from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .actions_get_response_rules import ActionsGetResponse_rules
    from .actions_get_response_transforms import ActionsGetResponse_transforms

@dataclass
class ActionsGetResponse(Parsable):
    # The name of the action that you can perform on the item.
    name: Optional[str] = None
    # The list of conditions that are required in order to be able to perform the action. For example, you can only open a PCO's budgetStatus and costStatus when they are in a draft state.
    rules: Optional[list[ActionsGetResponse_rules]] = None
    # The list of changes that you can perform on the associated item.
    transforms: Optional[list[ActionsGetResponse_transforms]] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ActionsGetResponse:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ActionsGetResponse
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ActionsGetResponse()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .actions_get_response_rules import ActionsGetResponse_rules
        from .actions_get_response_transforms import ActionsGetResponse_transforms

        from .actions_get_response_rules import ActionsGetResponse_rules
        from .actions_get_response_transforms import ActionsGetResponse_transforms

        fields: dict[str, Callable[[Any], None]] = {
            "name": lambda n : setattr(self, 'name', n.get_str_value()),
            "rules": lambda n : setattr(self, 'rules', n.get_collection_of_object_values(ActionsGetResponse_rules)),
            "transforms": lambda n : setattr(self, 'transforms', n.get_collection_of_object_values(ActionsGetResponse_transforms)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("name", self.name)
        writer.write_collection_of_object_values("rules", self.rules)
        writer.write_collection_of_object_values("transforms", self.transforms)
    

