from enum import Enum

class GetSortQueryParameterType(str, Enum):
    Name = "name",
    NameAsc = "name asc",
    Desc = "desc",
    SortFieldAscOrDesc = "sort=<field> [asc or desc]",
    LastUpdatedAt = "lastUpdatedAt",
    UpdatedByName = "updatedByName",
    SortNameAsc = "sort=name asc",
    SortLastUpdatedAtDesc = "sort=lastUpdatedAt desc",
    LastUpdatedAtAsc = "lastUpdatedAt asc",
    UpdatedByNameAsc = "updatedByName asc",
    NameDesc = "name desc",
    LastUpdatedAtDesc = "lastUpdatedAt desc",
    UpdatedByNameDesc = "updatedByName desc",

