from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class ValuesBatchUpdatePutResponse_tabularValues_worklogEntries(Parsable):
    # Indicates if the work log row has been deleted.
    deleted: Optional[bool] = None
    # A text description of the work performed.
    description: Optional[str] = None
    # Number of workers.
    headcount: Optional[int] = None
    # Unique identifier for the work log row.
    id: Optional[str] = None
    # Total duration of work performed (in milliseconds).
    timespan: Optional[int] = None
    # A text field indicating the worker's trade.
    trade: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ValuesBatchUpdatePutResponse_tabularValues_worklogEntries:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ValuesBatchUpdatePutResponse_tabularValues_worklogEntries
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ValuesBatchUpdatePutResponse_tabularValues_worklogEntries()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "deleted": lambda n : setattr(self, 'deleted', n.get_bool_value()),
            "description": lambda n : setattr(self, 'description', n.get_str_value()),
            "headcount": lambda n : setattr(self, 'headcount', n.get_int_value()),
            "id": lambda n : setattr(self, 'id', n.get_str_value()),
            "timespan": lambda n : setattr(self, 'timespan', n.get_int_value()),
            "trade": lambda n : setattr(self, 'trade', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_bool_value("deleted", self.deleted)
        writer.write_str_value("description", self.description)
        writer.write_int_value("headcount", self.headcount)
        writer.write_str_value("id", self.id)
        writer.write_int_value("timespan", self.timespan)
        writer.write_str_value("trade", self.trade)
    

