from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class StatusStepSetsPostRequestBody_values(Parsable):
    # The color of the status as the status appears in the Assets UI.This field is not restricted as it is primarily a tool for the Assets UI to use.However, there are only certain colors that the Autodesk Construction Cloud Assets UI knows how tooperate with. Understood color values are: ``adsk-black``, ``adsk-white``, ``adsk-charcoal-900``,``adsk-charcoal-800``, ``adsk-charcoal-700``, ``adsk-charcoal-600``, ``adsk-charcoal-500``,``adsk-charcoal-400``, ``adsk-charcoal-300``, ``adsk-charcoal-200``, ``adsk-charcoal-100``,``adsk-charcoal-050``, ``adsk-blue-700``, ``adsk-blue-500``, ``adsk-blue-300``, ``adsk-blue-100``,``adsk-red-700``, ``adsk-red-500``, ``adsk-red-300``, ``adsk-green-700``, ``adsk-green-500``,``adsk-green-300``, ``adsk-yellow-orange-700``, ``adsk-yellow-orange-500``, ``adsk-yellow-orange-300``,``adsk-dark-blue-700``, ``adsk-dark-blue-500``, ``adsk-dark-blue-300``, ``adsk-pink-700``,``adsk-pink-500``, ``adsk-pink-300``, ``adsk-turquoise-700``, ``adsk-turquoise-500``,``adsk-turquoise-300``, ``adsk-purple-700``, ``adsk-purple-500``, ``adsk-purple-300``,``adsk-salmon-700``, ``adsk-salmon-500``, ``adsk-salmon-300``, ``adsk-brown-700``, ``adsk-brown-500``,``adsk-brown-300``.Using colors other than those specified here is not disallowed, but may result in unexpected behavior inthe Assets UI.
    color: Optional[str] = None
    # A description of the status.
    description: Optional[str] = None
    # The display label of the status. This label appears in the Assets UI when viewing statuses. The label mustbe unique within this status set, but does not need to be unique within the project (in other words, thesame label can be used in multiple status sets in the same project). ``Uniqueness`` in this context meanscase-insensitive.
    label: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> StatusStepSetsPostRequestBody_values:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: StatusStepSetsPostRequestBody_values
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return StatusStepSetsPostRequestBody_values()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "color": lambda n : setattr(self, 'color', n.get_str_value()),
            "description": lambda n : setattr(self, 'description', n.get_str_value()),
            "label": lambda n : setattr(self, 'label', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("color", self.color)
        writer.write_str_value("description", self.description)
        writer.write_str_value("label", self.label)
    

