from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .me_get_response_permitted_actions_create_rfi_permitted_statuses import MeGetResponse_permittedActions_createRfi_permittedStatuses

@dataclass
class MeGetResponse_permittedActions_createRfi(Parsable):
    """
    The user’s permissions for creating RFIs.Note that if this field is present, the user is permitted to create RFIs in the project.
    """
    # The list of statuses the user is permitted to transition an RFI to, without differentiating between workflow types (e.g., ``us`` and ``emea``).
    permitted_statuses: Optional[MeGetResponse_permittedActions_createRfi_permittedStatuses] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> MeGetResponse_permittedActions_createRfi:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: MeGetResponse_permittedActions_createRfi
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return MeGetResponse_permittedActions_createRfi()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .me_get_response_permitted_actions_create_rfi_permitted_statuses import MeGetResponse_permittedActions_createRfi_permittedStatuses

        from .me_get_response_permitted_actions_create_rfi_permitted_statuses import MeGetResponse_permittedActions_createRfi_permittedStatuses

        fields: dict[str, Callable[[Any], None]] = {
            "permittedStatuses": lambda n : setattr(self, 'permitted_statuses', n.get_object_value(MeGetResponse_permittedActions_createRfi_permittedStatuses)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_object_value("permittedStatuses", self.permitted_statuses)
    

