from enum import Enum

class GetFilterStatusQueryParameterType(str, Enum):
    FilterStatusINACTIVE = "filter[status]=INACTIVE",
    ACTIVE = "ACTIVE",
    INACTIVE = "INACTIVE",
    FilterInitiator = "filter[initiator]",

