from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .queries_post_request_body_columns import QueriesPostRequestBody_columns
    from .queries_post_request_body_query import QueriesPostRequestBody_query

@dataclass
class QueriesPostRequestBody(Parsable):
    # `SQL AST for describing columns/projections </en/docs/acc/v1/tutorials/model-properties/query-ref/>`_
    columns: Optional[QueriesPostRequestBody_columns] = None
    # `SQL AST for binary expression/filter </en/docs/acc/v1/tutorials/model-properties/query-ref/>`_
    query: Optional[QueriesPostRequestBody_query] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> QueriesPostRequestBody:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: QueriesPostRequestBody
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return QueriesPostRequestBody()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .queries_post_request_body_columns import QueriesPostRequestBody_columns
        from .queries_post_request_body_query import QueriesPostRequestBody_query

        from .queries_post_request_body_columns import QueriesPostRequestBody_columns
        from .queries_post_request_body_query import QueriesPostRequestBody_query

        fields: dict[str, Callable[[Any], None]] = {
            "columns": lambda n : setattr(self, 'columns', n.get_object_value(QueriesPostRequestBody_columns)),
            "query": lambda n : setattr(self, 'query', n.get_object_value(QueriesPostRequestBody_query)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_object_value("columns", self.columns)
        writer.write_object_value("query", self.query)
    

