from __future__ import annotations
from collections.abc import Callable
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .assets.assets_request_builder import AssetsRequestBuilder
    from .assets_batch_create.assets_batch_create_request_builder import AssetsBatchCreateRequestBuilder
    from .assets_batch_delete.assets_batch_delete_request_builder import AssetsBatchDeleteRequestBuilder
    from .assets_batch_get.assets_batch_get_request_builder import AssetsBatchGetRequestBuilder
    from .assets_batch_patch.assets_batch_patch_request_builder import AssetsBatchPatchRequestBuilder

class WithProjectItemRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /construction/assets/v2/projects/{projectId}
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new WithProjectItemRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/construction/assets/v2/projects/{projectId}", path_parameters)
    
    @property
    def assets(self) -> AssetsRequestBuilder:
        """
        The assets property
        """
        from .assets.assets_request_builder import AssetsRequestBuilder

        return AssetsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def assets_batch_create(self) -> AssetsBatchCreateRequestBuilder:
        """
        The assetsBatchCreate property
        """
        from .assets_batch_create.assets_batch_create_request_builder import AssetsBatchCreateRequestBuilder

        return AssetsBatchCreateRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def assets_batch_delete(self) -> AssetsBatchDeleteRequestBuilder:
        """
        The assetsBatchDelete property
        """
        from .assets_batch_delete.assets_batch_delete_request_builder import AssetsBatchDeleteRequestBuilder

        return AssetsBatchDeleteRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def assets_batch_get(self) -> AssetsBatchGetRequestBuilder:
        """
        The assetsBatchGet property
        """
        from .assets_batch_get.assets_batch_get_request_builder import AssetsBatchGetRequestBuilder

        return AssetsBatchGetRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def assets_batch_patch(self) -> AssetsBatchPatchRequestBuilder:
        """
        The assetsBatchPatch property
        """
        from .assets_batch_patch.assets_batch_patch_request_builder import AssetsBatchPatchRequestBuilder

        return AssetsBatchPatchRequestBuilder(self.request_adapter, self.path_parameters)
    

