from __future__ import annotations
from collections.abc import Callable
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Optional, TYPE_CHECKING, Union
from uuid import UUID

if TYPE_CHECKING:
    from .item.with_container_item_request_builder import WithContainerItemRequestBuilder

class ContainersRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /bim360/clash/v3/containers
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new ContainersRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/bim360/clash/v3/containers", path_parameters)
    
    def by_container_id(self,container_id: UUID) -> WithContainerItemRequestBuilder:
        """
        Gets an item from the Autodesk.ACC.bim360.clash.v3.containers.item collection
        param container_id: The GUID that uniquely identifies the container.
        Returns: WithContainerItemRequestBuilder
        """
        if container_id is None:
            raise TypeError("container_id cannot be null.")
        from .item.with_container_item_request_builder import WithContainerItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["containerId"] = container_id
        return WithContainerItemRequestBuilder(self.request_adapter, url_tpl_params)
    

