from enum import Enum

class ValuesBatchUpdatePutRequestBody_tabularValues_columns_columnName(str, Enum):
    Trade = "trade",
    TextVal = "textVal",
    Timespan = "timespan",
    TimespanVal = "timespanVal",
    Headcount = "headcount",
    NumberVal = "numberVal",
    Description = "description",
    Item = "item",
    Quantity = "quantity",
    Unit = "unit",

