from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class WithErrorCodeNameGetResponse(Parsable):
    # A description of the error.
    description: Optional[str] = None
    # The HTTP status code typically returned when this error occurs.Note that there may be exceptions, for example, if an internal server erroroccurs the status code associated with this error may be different.
    http_status_code: Optional[float] = None
    # The metadata keys relevant to the error code.
    metadata_keys: Optional[list[str]] = None
    # The error code name.
    name: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> WithErrorCodeNameGetResponse:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: WithErrorCodeNameGetResponse
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return WithErrorCodeNameGetResponse()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "description": lambda n : setattr(self, 'description', n.get_str_value()),
            "httpStatusCode": lambda n : setattr(self, 'http_status_code', n.get_float_value()),
            "metadataKeys": lambda n : setattr(self, 'metadata_keys', n.get_collection_of_primitive_values(str)),
            "name": lambda n : setattr(self, 'name', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("description", self.description)
        writer.write_float_value("httpStatusCode", self.http_status_code)
        writer.write_collection_of_primitive_values("metadataKeys", self.metadata_keys)
        writer.write_str_value("name", self.name)
    

