from enum import Enum

class ContentViewsGetResponse_results_view_SheetView_calibration_units(str, Enum):
    FT_AND_DECIMAL_IN = "FT_AND_DECIMAL_IN",
    FT_AND_FRACTIONAL_IN = "FT_AND_FRACTIONAL_IN",
    M = "M",
    CM = "CM",
    MM = "MM",

