from enum import Enum

class TakeoffTypesGetResponse_results_shapeType(str, Enum):
    CIRCLE = "CIRCLE",
    TRIANGLE = "TRIANGLE",
    SQUARE = "SQUARE",
    DIAMOND = "DIAMOND",
    CHECKMARK = "CHECKMARK",

