from enum import Enum

class WorkflowsGetResponse_results_steps_dueDateType(str, Enum):
    REVIEWER = "REVIEWER",
    APPROVER = "APPROVER",
    CALENDAR_DAY = "CALENDAR_DAY",
    WORKDAY = "WORKDAY",

