from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class WithItemGetResponse_permittedActions_transitions_stateTo(Parsable):
    """
    The target state of the transition, indicating the next position of the submittal item in the workflow.
    """
    # The unique ID of the target state. For example, ``mgr-1``, ``mgr-2``, ``void``.
    id: Optional[str] = None
    # The name of the target state. For example, ``Manager Review``, ``Manager Final Review``, ``Void``.
    name: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> WithItemGetResponse_permittedActions_transitions_stateTo:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: WithItemGetResponse_permittedActions_transitions_stateTo
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return WithItemGetResponse_permittedActions_transitions_stateTo()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "id": lambda n : setattr(self, 'id', n.get_str_value()),
            "name": lambda n : setattr(self, 'name', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("id", self.id)
        writer.write_str_value("name", self.name)
    

