from enum import Enum

class WithUploadGetResponse_status(str, Enum):
    PENDING = "PENDING",
    PROCESSING = "PROCESSING",
    IN_REVIEW = "IN_REVIEW",
    FAILED = "FAILED",
    UPDATING_VERSION_SET = "UPDATING_VERSION_SET",
    PUBLISHING = "PUBLISHING",
    PUBLISHED = "PUBLISHED",

