from __future__ import annotations
import datetime
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union
from uuid import UUID

@dataclass
class WithPackageGetResponse(Parsable):
    # The date and time when the resource was created, in the following format: ``YYYY-MM-DDThh:mm:ssZ``.
    created_at: Optional[datetime.datetime] = None
    # The package ID.
    id: Optional[UUID] = None
    # The package name (user defined).Corresponding UI name: ``Title``.Max length: 64
    name: Optional[str] = None
    # The date and time when the resource was last updated, in the following format: ``YYYY-MM-DDThh:mm:ssZ``.
    updated_at: Optional[datetime.datetime] = None
    # The name of the user who last updated the resource.
    updated_by_name: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> WithPackageGetResponse:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: WithPackageGetResponse
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return WithPackageGetResponse()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "createdAt": lambda n : setattr(self, 'created_at', n.get_datetime_value()),
            "id": lambda n : setattr(self, 'id', n.get_uuid_value()),
            "name": lambda n : setattr(self, 'name', n.get_str_value()),
            "updatedAt": lambda n : setattr(self, 'updated_at', n.get_datetime_value()),
            "updatedByName": lambda n : setattr(self, 'updated_by_name', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_datetime_value("createdAt", self.created_at)
        writer.write_uuid_value("id", self.id)
        writer.write_str_value("name", self.name)
        writer.write_datetime_value("updatedAt", self.updated_at)
        writer.write_str_value("updatedByName", self.updated_by_name)
    

