from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .workflows_post_request_body_additional_approval_status_options_value import WorkflowsPostRequestBody_additionalApprovalStatusOptions_value

@dataclass
class WorkflowsPostRequestBody_additionalApprovalStatusOptions(Parsable):
    # The display name shown in the UI. It m ust be unique across all status options (built-in and custom).Maximum length: 255 characters.Max length: 255
    label: Optional[str] = None
    # The value representing the approval outcome. Possible values: ``APPROVED``, ``REJECTED``.
    value: Optional[WorkflowsPostRequestBody_additionalApprovalStatusOptions_value] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> WorkflowsPostRequestBody_additionalApprovalStatusOptions:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: WorkflowsPostRequestBody_additionalApprovalStatusOptions
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return WorkflowsPostRequestBody_additionalApprovalStatusOptions()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .workflows_post_request_body_additional_approval_status_options_value import WorkflowsPostRequestBody_additionalApprovalStatusOptions_value

        from .workflows_post_request_body_additional_approval_status_options_value import WorkflowsPostRequestBody_additionalApprovalStatusOptions_value

        fields: dict[str, Callable[[Any], None]] = {
            "label": lambda n : setattr(self, 'label', n.get_str_value()),
            "value": lambda n : setattr(self, 'value', n.get_enum_value(WorkflowsPostRequestBody_additionalApprovalStatusOptions_value)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("label", self.label)
        writer.write_enum_value("value", self.value)
    

