from __future__ import annotations
import datetime
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from .form_templates_get_response import FormTemplatesGetResponse
    from .get_sort_order_query_parameter_type import GetSortOrderQueryParameterType
    from .item.with_template_item_request_builder import WithTemplateItemRequestBuilder

class FormTemplatesRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /construction/forms/v1/projects/{projectId}/form-templates
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new FormTemplatesRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/construction/forms/v1/projects/{projectId}/form-templates{?limit*,offset*,sortOrder*,updatedAfter*,updatedBefore*}", path_parameters)
    
    def by_template_id(self,template_id: str) -> WithTemplateItemRequestBuilder:
        """
        Gets an item from the Autodesk.ACC.construction.forms.v1.projects.item.formTemplates.item collection
        param template_id: The unique identifier of the form template.Use `GET form-templates </en/docs/acc/v1/reference/http/forms-form-templates-GET/>`_ to retrieve the template ID.
        Returns: WithTemplateItemRequestBuilder
        """
        if template_id is None:
            raise TypeError("template_id cannot be null.")
        from .item.with_template_item_request_builder import WithTemplateItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["templateId"] = template_id
        return WithTemplateItemRequestBuilder(self.request_adapter, url_tpl_params)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[FormTemplatesRequestBuilderGetQueryParameters]] = None) -> Optional[FormTemplatesGetResponse]:
        """
        Returns all project's form templates the user has access to.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[FormTemplatesGetResponse]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .form_templates_get_response import FormTemplatesGetResponse

        return await self.request_adapter.send_async(request_info, FormTemplatesGetResponse, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[FormTemplatesRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        Returns all project's form templates the user has access to.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def with_url(self,raw_url: str) -> FormTemplatesRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: FormTemplatesRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return FormTemplatesRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class FormTemplatesRequestBuilderGetQueryParameters():
        """
        Returns all project's form templates the user has access to.
        """
        def get_query_parameter(self,original_name: str) -> str:
            """
            Maps the query parameters names to their encoded names for the URI template parsing.
            param original_name: The original query parameter name in the class.
            Returns: str
            """
            if original_name is None:
                raise TypeError("original_name cannot be null.")
            if original_name == "sort_order":
                return "sortOrder"
            if original_name == "updated_after":
                return "updatedAfter"
            if original_name == "updated_before":
                return "updatedBefore"
            if original_name == "limit":
                return "limit"
            if original_name == "offset":
                return "offset"
            return original_name
        
        # The number of records to return in a single request. Can be a number between 1 and 50. Defaults to 50.
        limit: Optional[int] = None

        # The number of records to skip before returning the result records. Defaults to 0. Increase this value in subsequent requests to continue getting results when the number of records exceeds the requested limit.
        offset: Optional[int] = None

        # Return Templates in specified sorted order.Possible values: ``desc``, ``asc``
        sort_order: Optional[GetSortOrderQueryParameterType] = None

        # Return Templates updated after specified time.
        updated_after: Optional[datetime.datetime] = None

        # Return Templates updated before specified time.
        updated_before: Optional[datetime.datetime] = None

    
    @dataclass
    class FormTemplatesRequestBuilderGetRequestConfiguration(RequestConfiguration[FormTemplatesRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    

