from enum import Enum

class CustomAttributesBatchGetPostResponse_results_dataType(str, Enum):
    Boolean = "boolean",
    True_ = "true",
    False_ = "false",
    Text = "text",
    Numeric = "numeric",
    Date = "date",
    TwoZeroTwoOne = "2021",
    Select = "select",
    EnumValues = "enumValues",
    Multi_select = "multi_select",

