from enum import Enum

class SmartregisterGetResponse_specCategory(str, Enum):
    TestReports = "Test Reports",
    ShopDrawings = "Shop Drawings",
    Schedules = "Schedules",
    Samples = "Samples",
    SampleWarranty = "Sample Warranty",
    Reports = "Reports",
    QualificationData = "Qualification Data",
    QUALITYASSURANCE = "QUALITY ASSURANCE",
    ProductData = "Product Data",
    PerformanceData = "Performance Data",
    MfgInstructions = "Mfg. Instructions",
    MeetingConferences = "Meeting/Conferences",
    Drawings = "Drawings",
    Delegated = "Delegated",
    Certifications = "Certifications",
    Certificates = "Certificates",
    Calculations = "Calculations",
    AtticStock = "Attic Stock",
    Demonstrations = "Demonstrations",
    GeneralWarranties = "General Warranties",
    OMManuals = "O&M Manuals",
    SpecialWarranties = "Special Warranties",
    LEED = "LEED",
    As_ = "As",
    TESTSANDINSPECTIONS = "TESTS AND INSPECTIONS",
    General = "General",
    ManufacturersInstructions = "Manufacturers Instructions",
    Substitutions = "Substitutions",
    MixDesign = "Mix Design",
    Others = "Others",

