from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .documents_get_response_results_approve_status_value import DocumentsGetResponse_results_approveStatus_value

@dataclass
class DocumentsGetResponse_results_approveStatus(Parsable):
    """
    The approval status of the file version.For more information, see `File Review Statuses <https://help.autodesk.com/view/DOCS/ENU/?guid=BIM360D_Document_Management_About_Reviews_Reviews_FAQs_Reference_html#file-review-statuses>`_ documentation.
    """
    # The customized label of the approval status.Max length: 255
    label: Optional[str] = None
    # The value of the approval status.Possible values: ``APPROVED``, ``REJECTED``
    value: Optional[DocumentsGetResponse_results_approveStatus_value] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> DocumentsGetResponse_results_approveStatus:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: DocumentsGetResponse_results_approveStatus
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return DocumentsGetResponse_results_approveStatus()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .documents_get_response_results_approve_status_value import DocumentsGetResponse_results_approveStatus_value

        from .documents_get_response_results_approve_status_value import DocumentsGetResponse_results_approveStatus_value

        fields: dict[str, Callable[[Any], None]] = {
            "label": lambda n : setattr(self, 'label', n.get_str_value()),
            "value": lambda n : setattr(self, 'value', n.get_enum_value(DocumentsGetResponse_results_approveStatus_value)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("label", self.label)
        writer.write_enum_value("value", self.value)
    

