from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .exports_post_request_body_options import ExportsPostRequestBody_options

@dataclass
class ExportsPostRequestBody(Parsable):
    # A list of file version URNs. A maximum of 200 files may be included.
    file_versions: Optional[list[str]] = None
    # The criteria for the markups and links to include with the exported files.Note that unpublished markups are those visible only to their creator.
    options: Optional[ExportsPostRequestBody_options] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ExportsPostRequestBody:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ExportsPostRequestBody
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ExportsPostRequestBody()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .exports_post_request_body_options import ExportsPostRequestBody_options

        from .exports_post_request_body_options import ExportsPostRequestBody_options

        fields: dict[str, Callable[[Any], None]] = {
            "fileVersions": lambda n : setattr(self, 'file_versions', n.get_collection_of_primitive_values(str)),
            "options": lambda n : setattr(self, 'options', n.get_object_value(ExportsPostRequestBody_options)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_collection_of_primitive_values("fileVersions", self.file_versions)
        writer.write_object_value("options", self.options)
    

