from enum import Enum

class ValuesBatchUpdatePutRequestBody_tabularValues_table(str, Enum):
    WorklogEntries = "worklogEntries",
    MaterialsEntries = "materialsEntries",
    EquipmentEntries = "equipmentEntries",

