from enum import Enum

class GetSortQueryParameterType(str, Enum):
    Name = "name",
    NameAsc = "name asc",
    Desc = "desc",
    SortFieldAscOrDesc = "sort=<field> [asc or desc]",
    Title = "title",
    Version = "version",
    LastUpdatedAt = "lastUpdatedAt",
    UpdatedByName = "updatedByName",
    SortNameAsc = "sort=name asc",
    SortLastUpdatedAtDesc = "sort=lastUpdatedAt desc",

