from __future__ import annotations
from collections.abc import Callable
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .assigned.assigned_request_builder import AssignedRequestBuilder
    from .closed.closed_request_builder import ClosedRequestBuilder
    from .grouped.grouped_request_builder import GroupedRequestBuilder

class ClashesRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /bim360/clash/v3/containers/{containerId}/modelsets/{modelSetId}/clashes
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new ClashesRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/bim360/clash/v3/containers/{containerId}/modelsets/{modelSetId}/clashes", path_parameters)
    
    @property
    def assigned(self) -> AssignedRequestBuilder:
        """
        The assigned property
        """
        from .assigned.assigned_request_builder import AssignedRequestBuilder

        return AssignedRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def closed(self) -> ClosedRequestBuilder:
        """
        The closed property
        """
        from .closed.closed_request_builder import ClosedRequestBuilder

        return ClosedRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def grouped(self) -> GroupedRequestBuilder:
        """
        The grouped property
        """
        from .grouped.grouped_request_builder import GroupedRequestBuilder

        return GroupedRequestBuilder(self.request_adapter, self.path_parameters)
    

