from enum import Enum

class TakeoffTypesGetResponse_results_primaryQuantityDefinition_unitOfMeasure(str, Enum):
    EA = "EA",
    IN_ = "IN",
    LF = "LF",
    YD = "YD",
    SI = "SI",
    SF = "SF",
    SY = "SY",
    CI = "CI",
    CF = "CF",
    CY = "CY",
    LBS = "LBS",
    TON = "TON",
    MM = "MM",
    M = "M",
    M2 = "M2",
    M3 = "M3",
    KG = "KG",
    T = "T",

