from enum import Enum

class WithRfiGetResponse_workflowType(str, Enum):
    US = "US",
    EU = "EU",
    Submitted = "submitted",
    OpenRev1 = "openRev1",
    AnsweredManager = "answeredManager",
    Status = "status",
    PreviousStatus = "previousStatus",

