from __future__ import annotations
from collections.abc import Callable
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .clashes.clashes_request_builder import ClashesRequestBuilder
    from .clashes_reopen.clashes_reopen_request_builder import ClashesReopenRequestBuilder
    from .screenshots.screenshots_request_builder import ScreenshotsRequestBuilder
    from .tests.tests_request_builder import TestsRequestBuilder
    from .versions.versions_request_builder import VersionsRequestBuilder

class WithModelSetItemRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /bim360/clash/v3/containers/{containerId}/modelsets/{modelSetId}
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new WithModelSetItemRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/bim360/clash/v3/containers/{containerId}/modelsets/{modelSetId}", path_parameters)
    
    @property
    def clashes(self) -> ClashesRequestBuilder:
        """
        The clashes property
        """
        from .clashes.clashes_request_builder import ClashesRequestBuilder

        return ClashesRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def clashes_reopen(self) -> ClashesReopenRequestBuilder:
        """
        The clashesReopen property
        """
        from .clashes_reopen.clashes_reopen_request_builder import ClashesReopenRequestBuilder

        return ClashesReopenRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def screenshots(self) -> ScreenshotsRequestBuilder:
        """
        The screenshots property
        """
        from .screenshots.screenshots_request_builder import ScreenshotsRequestBuilder

        return ScreenshotsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def tests(self) -> TestsRequestBuilder:
        """
        The tests property
        """
        from .tests.tests_request_builder import TestsRequestBuilder

        return TestsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def versions(self) -> VersionsRequestBuilder:
        """
        The versions property
        """
        from .versions.versions_request_builder import VersionsRequestBuilder

        return VersionsRequestBuilder(self.request_adapter, self.path_parameters)
    

