from enum import Enum

class SearchRfisPostResponse_results_previousStatus(str, Enum):
    Draft = "draft",
    Submitted = "submitted",
    Open = "open",
    Answered = "answered",
    Rejected = "rejected",
    Closed = "closed",
    Void = "void",
    OpenRev1 = "openRev1",
    OpenRev2 = "openRev2",
    AnsweredRev1 = "answeredRev1",
    AnsweredManager = "answeredManager",
    WorkflowType = "workflowType",

