from enum import Enum

class SearchRfisPostRequestBody_sort_field(str, Enum):
    CreatedAt = "createdAt",
    Status = "status",
    DueDate = "dueDate",
    Title = "title",
    Location = "location",
    UpdatedAt = "updatedAt",
    ClosedAt = "closedAt",
    CostImpact = "costImpact",
    ScheduleImpact = "scheduleImpact",
    Priority = "priority",
    Discipline = "discipline",
    Category = "category",
    Reference = "reference",
    CustomIdentifier = "customIdentifier",
    CustomAttribute = "customAttribute",

