from enum import Enum

class ClassificationsImportPostRequestBody_classifications_measurementType(str, Enum):
    AREA = "AREA",
    COUNT = "COUNT",
    DISTANCE = "DISTANCE",
    VOLUME = "VOLUME",

