from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class WorkflowsPostResponse_additionalOptions(Parsable):
    """
    Workflow-level settings that control whether the initiator can modify certain fields when starting a review.
    """
    # (``Allow Initiators to edit the review`` in the UI). Indicates whether the initiator can adjust reviewer assignments and step durations.``true``: the initiator can change reviewer assignments and durations.``false``: (default) reviewers and durations are fixed.
    allow_initiator_to_edit: Optional[bool] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> WorkflowsPostResponse_additionalOptions:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: WorkflowsPostResponse_additionalOptions
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return WorkflowsPostResponse_additionalOptions()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "allowInitiatorToEdit": lambda n : setattr(self, 'allow_initiator_to_edit', n.get_bool_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_bool_value("allowInitiatorToEdit", self.allow_initiator_to_edit)
    

