from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .budgets_import_post_request_body_data import BudgetsImportPostRequestBody_data

@dataclass
class BudgetsImportPostRequestBody(Parsable):
    # ``true`` if you want to append the new budgets to the project.``false`` if you want to purge existing budgets before importing the new budgets.
    append: Optional[bool] = None
    # A list of budget.
    data: Optional[list[BudgetsImportPostRequestBody_data]] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> BudgetsImportPostRequestBody:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: BudgetsImportPostRequestBody
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return BudgetsImportPostRequestBody()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .budgets_import_post_request_body_data import BudgetsImportPostRequestBody_data

        from .budgets_import_post_request_body_data import BudgetsImportPostRequestBody_data

        fields: dict[str, Callable[[Any], None]] = {
            "append": lambda n : setattr(self, 'append', n.get_bool_value()),
            "data": lambda n : setattr(self, 'data', n.get_collection_of_object_values(BudgetsImportPostRequestBody_data)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_bool_value("append", self.append)
        writer.write_collection_of_object_values("data", self.data)
    

