from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class ReviewsPostRequestBody_workflowOptions_copyFilesOptions(Parsable):
    """
    (``Copy approved files`` in the UI) Option for copying approved files when the review is complete.
    """
    # (``Then copy approved files to`` in the UI) The URN of the target folder where approved files will be copied.To find the folder URN, follow the first four steps of the `Upload Files to the ACC Files tool </en/docs/acc/v1/tutorials/files/upload-document-s3/>`_ tutorial and note the ``data.id`` field in the response. Use ``data.attributes.name`` or ``data.attributes.displayName`` to confirm you have the correct folder.
    folder_urn: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ReviewsPostRequestBody_workflowOptions_copyFilesOptions:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ReviewsPostRequestBody_workflowOptions_copyFilesOptions
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ReviewsPostRequestBody_workflowOptions_copyFilesOptions()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "folderUrn": lambda n : setattr(self, 'folder_urn', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("folderUrn", self.folder_urn)
    

