from __future__ import annotations
from collections.abc import Callable
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .classification_systems.classification_systems_request_builder import ClassificationSystemsRequestBuilder
    from .content_views.content_views_request_builder import ContentViewsRequestBuilder
    from .packages.packages_request_builder import PackagesRequestBuilder
    from .settings.settings_request_builder import SettingsRequestBuilder

class WithProjectItemRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /construction/takeoff/v1/projects/{projectId}
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new WithProjectItemRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/construction/takeoff/v1/projects/{projectId}", path_parameters)
    
    @property
    def classification_systems(self) -> ClassificationSystemsRequestBuilder:
        """
        The classificationSystems property
        """
        from .classification_systems.classification_systems_request_builder import ClassificationSystemsRequestBuilder

        return ClassificationSystemsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def content_views(self) -> ContentViewsRequestBuilder:
        """
        The contentViews property
        """
        from .content_views.content_views_request_builder import ContentViewsRequestBuilder

        return ContentViewsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def packages(self) -> PackagesRequestBuilder:
        """
        The packages property
        """
        from .packages.packages_request_builder import PackagesRequestBuilder

        return PackagesRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def settings(self) -> SettingsRequestBuilder:
        """
        The settings property
        """
        from .settings.settings_request_builder import SettingsRequestBuilder

        return SettingsRequestBuilder(self.request_adapter, self.path_parameters)
    

