from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class ExportsPostRequestBody_options_standardMarkups(Parsable):
    """
    The list of types of standard markups and their associated links that you want to include in the export.By default markups will be exported and hyperlinks will not be exported.
    """
    # ``true``: include links in the markups. Supported links are links to Sheets, Files, RFIs, Forms, Submittals, and Assets.``false``: (default) do not include links in markups.Note that if both ``includePublishedMarkups`` and ``includeUnpublishedMarkups`` are set to ``false``, this parameter will be treated as ``false``.
    include_markup_links: Optional[bool] = None
    # ``true``: (default) include all published standard markups in the exported sheets. Note that published markups are visible to all project members.``false``: export sheets without including published standard markups.
    include_published_markups: Optional[bool] = None
    # ``true``: (default) standard markups that are visible only to their creators will be included in the exported sheets.``false``: exported sheets will exclude unpublished markups.
    include_unpublished_markups: Optional[bool] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ExportsPostRequestBody_options_standardMarkups:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ExportsPostRequestBody_options_standardMarkups
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ExportsPostRequestBody_options_standardMarkups()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "includeMarkupLinks": lambda n : setattr(self, 'include_markup_links', n.get_bool_value()),
            "includePublishedMarkups": lambda n : setattr(self, 'include_published_markups', n.get_bool_value()),
            "includeUnpublishedMarkups": lambda n : setattr(self, 'include_unpublished_markups', n.get_bool_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_bool_value("includeMarkupLinks", self.include_markup_links)
        writer.write_bool_value("includePublishedMarkups", self.include_published_markups)
        writer.write_bool_value("includeUnpublishedMarkups", self.include_unpublished_markups)
    

