from enum import Enum

class GetFilterDataTypeQueryParameterType(str, Enum):
    List_ = "list",
    Dropdown = "dropdown",
    Text = "text",
    Paragraph = "paragraph",
    Numeric = "numeric",
    FilterDataTypeTextNumeric = "filter[dataType]=text,numeric",

