from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .versions_get_response_results_review_content_custom_attributes import VersionsGetResponse_results_reviewContent_customAttributes

@dataclass
class VersionsGetResponse_results_reviewContent(Parsable):
    """
    Review-specific metadata related to the file version.
    """
    # A list of custom attributes applied to the file during the review.
    custom_attributes: Optional[list[VersionsGetResponse_results_reviewContent_customAttributes]] = None
    # The pending file name assigned during the review.If the review is approved, this becomes the official version name.In most cases, this value is automatically generated according to the naming standard configured on the folder.
    name: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> VersionsGetResponse_results_reviewContent:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: VersionsGetResponse_results_reviewContent
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return VersionsGetResponse_results_reviewContent()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .versions_get_response_results_review_content_custom_attributes import VersionsGetResponse_results_reviewContent_customAttributes

        from .versions_get_response_results_review_content_custom_attributes import VersionsGetResponse_results_reviewContent_customAttributes

        fields: dict[str, Callable[[Any], None]] = {
            "customAttributes": lambda n : setattr(self, 'custom_attributes', n.get_collection_of_object_values(VersionsGetResponse_results_reviewContent_customAttributes)),
            "name": lambda n : setattr(self, 'name', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_collection_of_object_values("customAttributes", self.custom_attributes)
        writer.write_str_value("name", self.name)
    

