from enum import Enum

class PaymentsGetResponse_status(str, Enum):
    Draft = "draft",
    PendingInput = "pendingInput",
    Submitted = "submitted",
    Revise = "revise",
    Accepted = "accepted",
    Approved = "approved",
    Paid = "paid",

