from enum import Enum

class GetAssociationTypeQueryParameterType(str, Enum):
    Budget = "Budget",
    Contract = "Contract",
    CostItem = "CostItem",
    FormInstance = "FormInstance",
    Payment = "Payment",
    BudgetPayment = "BudgetPayment",
    Expense = "Expense",
    OCO = "OCO",
    SCO = "SCO",

