from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class ManifestGetResponse_prev_databases(Parsable):
    # OSS path for the attributes file.
    attributes: Optional[str] = None
    # DB ID.
    id: Optional[str] = None
    # OSS path for the IDs file.
    ids: Optional[str] = None
    # OSS path for the mapping file.
    mapping: Optional[str] = None
    # OSS path for the offsets file.
    offsets: Optional[str] = None
    # OSS path for the values file.
    values: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ManifestGetResponse_prev_databases:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ManifestGetResponse_prev_databases
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ManifestGetResponse_prev_databases()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "attributes": lambda n : setattr(self, 'attributes', n.get_str_value()),
            "id": lambda n : setattr(self, 'id', n.get_str_value()),
            "ids": lambda n : setattr(self, 'ids', n.get_str_value()),
            "mapping": lambda n : setattr(self, 'mapping', n.get_str_value()),
            "offsets": lambda n : setattr(self, 'offsets', n.get_str_value()),
            "values": lambda n : setattr(self, 'values', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("attributes", self.attributes)
        writer.write_str_value("id", self.id)
        writer.write_str_value("ids", self.ids)
        writer.write_str_value("mapping", self.mapping)
        writer.write_str_value("offsets", self.offsets)
        writer.write_str_value("values", self.values)
    

