from enum import Enum

class ReviewSheetsGetResponse_results_processingState(str, Enum):
    PROCESSING = "PROCESSING",
    AUDITING = "AUDITING",
    ROTATING = "ROTATING",
    READY = "READY",
    FAILED = "FAILED",
    PUBLISHING = "PUBLISHING",

