from enum import Enum

class GetSortQueryParameterType(str, Enum):
    SequenceIdDesc = "sequenceId desc",
    Asc = "asc",
    SortFieldAscOrDesc = "sort=<field> [asc or desc]",
    Status = "status",
    SequenceId = "sequenceId",
    Title = "title",
    SentByName = "sentByName",
    CreatedAt = "createdAt",
    DocumentsCount = "documentsCount",
    SortStatusAsc = "sort=status asc",
    SortCreatedAtDesc = "sort=createdAt desc",

