from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union
from uuid import UUID

if TYPE_CHECKING:
    from .content_views_get_response_results_type import ContentViewsGetResponse_results_type
    from .content_views_get_response_results_view import ContentViewsGetResponse_results_view

@dataclass
class ContentViewsGetResponse_results(Parsable):
    # The content view ID.
    id: Optional[UUID] = None
    # The content view type.Possible values: ``SHEET`` (2D Sheet), ``FILE_MODEL`` (3D Model).
    type: Optional[ContentViewsGetResponse_results_type] = None
    # The content view.
    view: Optional[ContentViewsGetResponse_results_view] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ContentViewsGetResponse_results:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ContentViewsGetResponse_results
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ContentViewsGetResponse_results()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .content_views_get_response_results_type import ContentViewsGetResponse_results_type
        from .content_views_get_response_results_view import ContentViewsGetResponse_results_view

        from .content_views_get_response_results_type import ContentViewsGetResponse_results_type
        from .content_views_get_response_results_view import ContentViewsGetResponse_results_view

        fields: dict[str, Callable[[Any], None]] = {
            "id": lambda n : setattr(self, 'id', n.get_uuid_value()),
            "type": lambda n : setattr(self, 'type', n.get_enum_value(ContentViewsGetResponse_results_type)),
            "view": lambda n : setattr(self, 'view', n.get_object_value(ContentViewsGetResponse_results_view)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_uuid_value("id", self.id)
        writer.write_enum_value("type", self.type)
        writer.write_object_value("view", self.view)
    

