from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .values_batch_update_put_request_body_custom_values import ValuesBatchUpdatePutRequestBody_customValues
    from .values_batch_update_put_request_body_tabular_values import ValuesBatchUpdatePutRequestBody_tabularValues

@dataclass
class ValuesBatchUpdatePutRequestBody(Parsable):
    # The list of non-tabular fields.
    custom_values: Optional[list[ValuesBatchUpdatePutRequestBody_customValues]] = None
    # The list of tabular fields.
    tabular_values: Optional[list[ValuesBatchUpdatePutRequestBody_tabularValues]] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ValuesBatchUpdatePutRequestBody:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ValuesBatchUpdatePutRequestBody
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ValuesBatchUpdatePutRequestBody()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .values_batch_update_put_request_body_custom_values import ValuesBatchUpdatePutRequestBody_customValues
        from .values_batch_update_put_request_body_tabular_values import ValuesBatchUpdatePutRequestBody_tabularValues

        from .values_batch_update_put_request_body_custom_values import ValuesBatchUpdatePutRequestBody_customValues
        from .values_batch_update_put_request_body_tabular_values import ValuesBatchUpdatePutRequestBody_tabularValues

        fields: dict[str, Callable[[Any], None]] = {
            "customValues": lambda n : setattr(self, 'custom_values', n.get_collection_of_object_values(ValuesBatchUpdatePutRequestBody_customValues)),
            "tabularValues": lambda n : setattr(self, 'tabular_values', n.get_collection_of_object_values(ValuesBatchUpdatePutRequestBody_tabularValues)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_collection_of_object_values("customValues", self.custom_values)
        writer.write_collection_of_object_values("tabularValues", self.tabular_values)
    

