from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .me_get_response_issues_filter import MeGetResponse_issues_filter
    from .me_get_response_issues_new import MeGetResponse_issues_new

@dataclass
class MeGetResponse_issues(Parsable):
    # Not relevant
    filter: Optional[MeGetResponse_issues_filter] = None
    # If this object appears in the response, it indicates that the user can create and modify issues.
    new: Optional[MeGetResponse_issues_new] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> MeGetResponse_issues:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: MeGetResponse_issues
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return MeGetResponse_issues()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .me_get_response_issues_filter import MeGetResponse_issues_filter
        from .me_get_response_issues_new import MeGetResponse_issues_new

        from .me_get_response_issues_filter import MeGetResponse_issues_filter
        from .me_get_response_issues_new import MeGetResponse_issues_new

        fields: dict[str, Callable[[Any], None]] = {
            "filter": lambda n : setattr(self, 'filter', n.get_object_value(MeGetResponse_issues_filter)),
            "new": lambda n : setattr(self, 'new', n.get_object_value(MeGetResponse_issues_new)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_object_value("filter", self.filter)
        writer.write_object_value("new", self.new)
    

