from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from .status_step_sets_get_response import StatusStepSetsGetResponse
    from .status_step_sets_post_request_body import StatusStepSetsPostRequestBody
    from .status_step_sets_post_response import StatusStepSetsPostResponse

class StatusStepSetsRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /construction/assets/v1/projects/{projectId}/status-step-sets
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new StatusStepSetsRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/construction/assets/v1/projects/{projectId}/status-step-sets{?cursorState*,filter%5BupdatedAt%5D*,includeDeleted*,limit*,renameConflicting*}", path_parameters)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[StatusStepSetsRequestBuilderGetQueryParameters]] = None) -> Optional[StatusStepSetsGetResponse]:
        """
        GET status-step-sets
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[StatusStepSetsGetResponse]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .status_step_sets_get_response import StatusStepSetsGetResponse

        return await self.request_adapter.send_async(request_info, StatusStepSetsGetResponse, None)
    
    async def post(self,body: StatusStepSetsPostRequestBody, request_configuration: Optional[RequestConfiguration[StatusStepSetsRequestBuilderPostQueryParameters]] = None) -> Optional[StatusStepSetsPostResponse]:
        """
        POST status-step-sets
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[StatusStepSetsPostResponse]
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = self.to_post_request_information(
            body, request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .status_step_sets_post_response import StatusStepSetsPostResponse

        return await self.request_adapter.send_async(request_info, StatusStepSetsPostResponse, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[StatusStepSetsRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        GET status-step-sets
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def to_post_request_information(self,body: StatusStepSetsPostRequestBody, request_configuration: Optional[RequestConfiguration[StatusStepSetsRequestBuilderPostQueryParameters]] = None) -> RequestInformation:
        """
        POST status-step-sets
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = RequestInformation(Method.POST, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        request_info.set_content_from_parsable(self.request_adapter, "application/json", body)
        return request_info
    
    def with_url(self,raw_url: str) -> StatusStepSetsRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: StatusStepSetsRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return StatusStepSetsRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class StatusStepSetsRequestBuilderGetQueryParameters():
        """
        GET status-step-sets
        """
        def get_query_parameter(self,original_name: str) -> str:
            """
            Maps the query parameters names to their encoded names for the URI template parsing.
            param original_name: The original query parameter name in the class.
            Returns: str
            """
            if original_name is None:
                raise TypeError("original_name cannot be null.")
            if original_name == "cursor_state":
                return "cursorState"
            if original_name == "filterupdated_at":
                return "filter%5BupdatedAt%5D"
            if original_name == "include_deleted":
                return "includeDeleted"
            if original_name == "limit":
                return "limit"
            return original_name
        
        # An opaque cursor token that identifies where the next page of paginated results should start. It's returned ineach paginated response so that it can be supplied in the next request to continue paginated results. If apaginated response contains no ``cursorState`` value, then there are no further pages to return.Omit this field to initiate a paginated request or to restart pagination.
        cursor_state: Optional[str] = None

        # A string that specifies a date and time or a date and time range at which all returned objects mast have beenupdated. A single date and time takes this format: ``YYYY-MM-DDThh:mm:ss.SSSZ``, A date and time range takes thisformat: ``YYYY-MM-DDThh:mm:ss.SSSZ..YYYY-MM-DDThh:mm:ss.SSSZ``. Range queries can be closed or open in eitherdirection: ``YYYY-MM-DDThh:mm:ss.SSSZ..`` or ``..YYYY-MM-DDThh:mm:ss.SSSZ``.
        filterupdated_at: Optional[str] = None

        # Whether or not soft-deleted object should be included in the response. If ``true``, soft-deleted objects are returned. If ``false``, they are not. The default is ``false``.
        include_deleted: Optional[bool] = None

        # The maximum number of objects that can be returned in a page. A request might return fewer objects than the limit if the Assets service runs out of specified objects to return - at the end of a set of paged results, for example. The maximum limit is ``200``; the default limit is ``25``.
        limit: Optional[int] = None

    
    @dataclass
    class StatusStepSetsRequestBuilderGetRequestConfiguration(RequestConfiguration[StatusStepSetsRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    
    @dataclass
    class StatusStepSetsRequestBuilderPostQueryParameters():
        """
        POST status-step-sets
        """
        def get_query_parameter(self,original_name: str) -> str:
            """
            Maps the query parameters names to their encoded names for the URI template parsing.
            param original_name: The original query parameter name in the class.
            Returns: str
            """
            if original_name is None:
                raise TypeError("original_name cannot be null.")
            if original_name == "rename_conflicting":
                return "renameConflicting"
            return original_name
        
        # Specifies that any inactive (deleted) entity with a conflicting name should be automatically renamedto avoid a conflict. Only supported by specific APIs.
        rename_conflicting: Optional[bool] = None

    
    @dataclass
    class StatusStepSetsRequestBuilderPostRequestConfiguration(RequestConfiguration[StatusStepSetsRequestBuilderPostQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    

