from enum import Enum

class TakeoffTypesGetResponse_results_propertyDefinitions_valueLocation(str, Enum):
    ValueLocation = "valueLocation",
    INSTANCE_WITH_TAKEOFF_TYPE_DEFAULT = "INSTANCE_WITH_TAKEOFF_TYPE_DEFAULT",
    TAKEOFF_TYPE = "TAKEOFF_TYPE",

