from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union
from uuid import UUID

@dataclass
class StatusStepSetsBatchGetPostResponse_results(Parsable):
    # The ID of the category to which the status set is assigned.
    category_id: Optional[str] = None
    # The ID of the category from which this status set was inherited - that is, the ancestor categoryto which the inherited status set was explicitly assigned. This field is only present when thisendpoint is set to return inherited status sets, and then only for inherited status sets.
    inherited_from_category_id: Optional[str] = None
    # The ID of the status set assigned to the category.
    status_step_set_id: Optional[UUID] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> StatusStepSetsBatchGetPostResponse_results:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: StatusStepSetsBatchGetPostResponse_results
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return StatusStepSetsBatchGetPostResponse_results()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "categoryId": lambda n : setattr(self, 'category_id', n.get_str_value()),
            "inheritedFromCategoryId": lambda n : setattr(self, 'inherited_from_category_id', n.get_str_value()),
            "statusStepSetId": lambda n : setattr(self, 'status_step_set_id', n.get_uuid_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("categoryId", self.category_id)
        writer.write_str_value("inheritedFromCategoryId", self.inherited_from_category_id)
        writer.write_uuid_value("statusStepSetId", self.status_step_set_id)
    

