from enum import Enum

class ItemsPostRequestBody_stateId(str, Enum):
    Draft = "draft",
    Sbc = "sbc",
    Mgr = "mgr",
    Subcontractor = "subcontractor",
    SubcontractorType = "subcontractorType",
    SubmitterDueDate = "submitterDueDate",
    Manager = "manager",

