from __future__ import annotations
from collections.abc import Callable
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .item.with_tree_item_request_builder import WithTreeItemRequestBuilder

class TreesRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /construction/locations/v2/projects/{projectId}/trees
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new TreesRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/construction/locations/v2/projects/{projectId}/trees", path_parameters)
    
    def by_tree_id(self,tree_id: str) -> WithTreeItemRequestBuilder:
        """
        Gets an item from the Autodesk.ACC.construction.locations.v2.projects.item.trees.item collection
        param tree_id: Must be ``default``. Currently a project can contain only the default tree.
        Returns: WithTreeItemRequestBuilder
        """
        if tree_id is None:
            raise TypeError("tree_id cannot be null.")
        from .item.with_tree_item_request_builder import WithTreeItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["treeId"] = tree_id
        return WithTreeItemRequestBuilder(self.request_adapter, url_tpl_params)
    

