from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .indexes_batch_status_post_request_body_versions_columns import IndexesBatchStatusPostRequestBody_versions_columns
    from .indexes_batch_status_post_request_body_versions_query import IndexesBatchStatusPostRequestBody_versions_query

@dataclass
class IndexesBatchStatusPostRequestBody_versions(Parsable):
    # `SQL AST for describing columns/projections </en/docs/acc/v1/tutorials/model-properties/query-ref/>`_
    columns: Optional[IndexesBatchStatusPostRequestBody_versions_columns] = None
    # `SQL AST for binary expression/filter </en/docs/acc/v1/tutorials/model-properties/query-ref/>`_
    query: Optional[IndexesBatchStatusPostRequestBody_versions_query] = None
    # file version urn.
    version_urn: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> IndexesBatchStatusPostRequestBody_versions:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: IndexesBatchStatusPostRequestBody_versions
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return IndexesBatchStatusPostRequestBody_versions()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .indexes_batch_status_post_request_body_versions_columns import IndexesBatchStatusPostRequestBody_versions_columns
        from .indexes_batch_status_post_request_body_versions_query import IndexesBatchStatusPostRequestBody_versions_query

        from .indexes_batch_status_post_request_body_versions_columns import IndexesBatchStatusPostRequestBody_versions_columns
        from .indexes_batch_status_post_request_body_versions_query import IndexesBatchStatusPostRequestBody_versions_query

        fields: dict[str, Callable[[Any], None]] = {
            "columns": lambda n : setattr(self, 'columns', n.get_object_value(IndexesBatchStatusPostRequestBody_versions_columns)),
            "query": lambda n : setattr(self, 'query', n.get_object_value(IndexesBatchStatusPostRequestBody_versions_query)),
            "versionUrn": lambda n : setattr(self, 'version_urn', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_object_value("columns", self.columns)
        writer.write_object_value("query", self.query)
        writer.write_str_value("versionUrn", self.version_urn)
    

