from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .recipients_get_response_external_members import RecipientsGetResponse_externalMembers
    from .recipients_get_response_recipients import RecipientsGetResponse_recipients

@dataclass
class RecipientsGetResponse(Parsable):
    # A list of external recipients included in the transmittal.
    external_members: Optional[list[RecipientsGetResponse_externalMembers]] = None
    # The list of project-member recipients included in the transmittal.
    recipients: Optional[list[RecipientsGetResponse_recipients]] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> RecipientsGetResponse:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: RecipientsGetResponse
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return RecipientsGetResponse()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .recipients_get_response_external_members import RecipientsGetResponse_externalMembers
        from .recipients_get_response_recipients import RecipientsGetResponse_recipients

        from .recipients_get_response_external_members import RecipientsGetResponse_externalMembers
        from .recipients_get_response_recipients import RecipientsGetResponse_recipients

        fields: dict[str, Callable[[Any], None]] = {
            "externalMembers": lambda n : setattr(self, 'external_members', n.get_collection_of_object_values(RecipientsGetResponse_externalMembers)),
            "recipients": lambda n : setattr(self, 'recipients', n.get_collection_of_object_values(RecipientsGetResponse_recipients)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_collection_of_object_values("externalMembers", self.external_members)
        writer.write_collection_of_object_values("recipients", self.recipients)
    

