from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .sheets_batch_update_post_request_body_updates import SheetsBatchUpdatePostRequestBody_updates

@dataclass
class SheetsBatchUpdatePostRequestBody(Parsable):
    # To find the IDs of the sheets you want to update, call `GET sheets </en/docs/acc/v1/reference/http/sheets-sheets-GET/>`_.- The max number of items is 200.
    ids: Optional[list[str]] = None
    # The list of updates.
    updates: Optional[list[SheetsBatchUpdatePostRequestBody_updates]] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> SheetsBatchUpdatePostRequestBody:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: SheetsBatchUpdatePostRequestBody
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return SheetsBatchUpdatePostRequestBody()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .sheets_batch_update_post_request_body_updates import SheetsBatchUpdatePostRequestBody_updates

        from .sheets_batch_update_post_request_body_updates import SheetsBatchUpdatePostRequestBody_updates

        fields: dict[str, Callable[[Any], None]] = {
            "ids": lambda n : setattr(self, 'ids', n.get_collection_of_primitive_values(str)),
            "updates": lambda n : setattr(self, 'updates', n.get_collection_of_object_values(SheetsBatchUpdatePostRequestBody_updates)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_collection_of_primitive_values("ids", self.ids)
        writer.write_collection_of_object_values("updates", self.updates)
    

