from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class TaxesGetResponse_results_summary(Parsable):
    # The total amount of the applied tax.
    amount: Optional[float] = None
    # The name of the applied tax (e.g., Sales Tax, VAT, State Tax, City Tax, Local Tax).
    name: Optional[str] = None
    # (optional) The rate of the tax applied.
    rate: Optional[str] = None
    # The type of tax applied, such as ``rate``.
    type: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> TaxesGetResponse_results_summary:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: TaxesGetResponse_results_summary
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return TaxesGetResponse_results_summary()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "amount": lambda n : setattr(self, 'amount', n.get_float_value()),
            "name": lambda n : setattr(self, 'name', n.get_str_value()),
            "rate": lambda n : setattr(self, 'rate', n.get_str_value()),
            "type": lambda n : setattr(self, 'type', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_float_value("amount", self.amount)
        writer.write_str_value("name", self.name)
        writer.write_str_value("rate", self.rate)
        writer.write_str_value("type", self.type)
    

