from __future__ import annotations
import datetime
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from .forms_get_response import FormsGetResponse
    from .item.with_form_item_request_builder import WithFormItemRequestBuilder

class FormsRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /construction/forms/v1/projects/{projectId}/forms
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new FormsRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/construction/forms/v1/projects/{projectId}/forms{?formDateMax*,formDateMin*,ids*,limit*,locationIds*,offset*,sortBy*,sortOrder*,statuses*,templateId*,updatedAfter*,updatedBefore*}", path_parameters)
    
    def by_form_id(self,form_id: str) -> WithFormItemRequestBuilder:
        """
        Gets an item from the Autodesk.ACC.construction.forms.v1.projects.item.forms.item collection
        param form_id: The unique identifier of the form.Use `GET forms </en/docs/acc/v1/reference/http/forms-forms-GET/>`_ to retrieve the form ID.
        Returns: WithFormItemRequestBuilder
        """
        if form_id is None:
            raise TypeError("form_id cannot be null.")
        from .item.with_form_item_request_builder import WithFormItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["formId"] = form_id
        return WithFormItemRequestBuilder(self.request_adapter, url_tpl_params)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[FormsRequestBuilderGetQueryParameters]] = None) -> Optional[FormsGetResponse]:
        """
        Returns a paginated list of forms in a project. Forms are sorted by updatedAt, most recent first.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[FormsGetResponse]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .forms_get_response import FormsGetResponse

        return await self.request_adapter.send_async(request_info, FormsGetResponse, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[FormsRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        Returns a paginated list of forms in a project. Forms are sorted by updatedAt, most recent first.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def with_url(self,raw_url: str) -> FormsRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: FormsRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return FormsRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class FormsRequestBuilderGetQueryParameters():
        """
        Returns a paginated list of forms in a project. Forms are sorted by updatedAt, most recent first.
        """
        def get_query_parameter(self,original_name: str) -> str:
            """
            Maps the query parameters names to their encoded names for the URI template parsing.
            param original_name: The original query parameter name in the class.
            Returns: str
            """
            if original_name is None:
                raise TypeError("original_name cannot be null.")
            if original_name == "form_date_max":
                return "formDateMax"
            if original_name == "form_date_min":
                return "formDateMin"
            if original_name == "location_ids":
                return "locationIds"
            if original_name == "sort_by":
                return "sortBy"
            if original_name == "sort_order":
                return "sortOrder"
            if original_name == "template_id":
                return "templateId"
            if original_name == "updated_after":
                return "updatedAfter"
            if original_name == "updated_before":
                return "updatedBefore"
            if original_name == "ids":
                return "ids"
            if original_name == "limit":
                return "limit"
            if original_name == "offset":
                return "offset"
            if original_name == "statuses":
                return "statuses"
            return original_name
        
        # Return Forms with formDate at or before specified date.
        form_date_max: Optional[str] = None

        # Return Forms with formDate at or after specified date.
        form_date_min: Optional[str] = None

        # An array of Form IDs to retrieve.
        ids: Optional[list[str]] = None

        # The number of records to return in a single request. Can be a number between 1 and 50. Defaults to 50.
        limit: Optional[int] = None

        # A sequence of location IDs. Each returned object must be associated with one of the locations specified by the IDs. For example, ?locationId=123e102a-36de-14e7-8c56-1b1234ccbba8&locationId=cee45678-fcc4-43ae-80a2-8ca819dfa70d. See the usage example in the `Retrieve Forms Associated With Locations </en/docs/acc/v1/tutorials/forms/retrieve-forms-based-on-locations/>`_ tutorial.
        location_ids: Optional[list[str]] = None

        # The number of records to skip before returning the result records. Defaults to 0. Increase this value in subsequent requests to continue getting results when the number of records exceeds the requested limit.
        offset: Optional[int] = None

        # Return Forms sorted by specified attribute.
        sort_by: Optional[str] = None

        # Return Forms in specified sorted order.
        sort_order: Optional[str] = None

        # Return Forms with given statuses.
        statuses: Optional[list[str]] = None

        # Return Forms on template with given ID.
        template_id: Optional[str] = None

        # Return Forms updated after a specified time.
        updated_after: Optional[datetime.datetime] = None

        # Return Forms updated before a specified time.
        updated_before: Optional[datetime.datetime] = None

    
    @dataclass
    class FormsRequestBuilderGetRequestConfiguration(RequestConfiguration[FormsRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    

