from enum import Enum

class PropertiesGetResponse_type(str, Enum):
    Text = "text",
    Multiline = "multiline",
    Richtext = "richtext",
    Options = "options",
    Boolean = "boolean",
    Integer = "integer",
    Percent = "percent",
    Currency = "currency",
    Number = "number",
    Datetime = "datetime",

