from enum import Enum

class WithRfiPatchResponse_permittedActions_updateRfi_permittedStatuses_wfUS_status(str, Enum):
    Draft = "draft",
    Submitted = "submitted",
    Open = "open",
    Answered = "answered",
    Rejected = "rejected",
    Closed = "closed",
    Void = "void",

