from enum import Enum

class DocumentsGetResponse_status(str, Enum):
    Pending = "Pending",
    Started = "Started",
    Completed = "Completed",
    Failed = "Failed",
    PendingSign = "PendingSign",
    Signed = "Signed",

