from enum import Enum

class SubCostItemsCopyPostRequestBody_from(str, Enum):
    Contract = "contract",
    Budget = "budget",
    Estimated = "estimated",
    Proposed = "proposed",
    Submitted = "submitted",
    Approved = "approved",
    Committed = "committed",

