from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class FormsGetResponse_data_tabularValues_materialsEntries(Parsable):
    # Indicates if the material log row has been deleted.
    deleted: Optional[bool] = None
    # Additional description of the materials.
    description: Optional[str] = None
    # Unique identifier for the material log row.
    id: Optional[str] = None
    # Text indicating the material used.
    item: Optional[str] = None
    # The quantity of material that was used.
    quantity: Optional[float] = None
    # The unit of measure for the quantity specified.
    unit: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> FormsGetResponse_data_tabularValues_materialsEntries:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: FormsGetResponse_data_tabularValues_materialsEntries
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return FormsGetResponse_data_tabularValues_materialsEntries()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "deleted": lambda n : setattr(self, 'deleted', n.get_bool_value()),
            "description": lambda n : setattr(self, 'description', n.get_str_value()),
            "id": lambda n : setattr(self, 'id', n.get_str_value()),
            "item": lambda n : setattr(self, 'item', n.get_str_value()),
            "quantity": lambda n : setattr(self, 'quantity', n.get_float_value()),
            "unit": lambda n : setattr(self, 'unit', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_bool_value("deleted", self.deleted)
        writer.write_str_value("description", self.description)
        writer.write_str_value("id", self.id)
        writer.write_str_value("item", self.item)
        writer.write_float_value("quantity", self.quantity)
        writer.write_str_value("unit", self.unit)
    

