from enum import Enum

class IssueAttributeMappingsGetResponse_results_mappedItemType(str, Enum):
    IssueType = "issueType",
    IssueCategory = "Issue Category",
    IssueSubtype = "issueSubtype",

