from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union
from uuid import UUID

if TYPE_CHECKING:
    from .issues_post_request_body_custom_attributes_value import IssuesPostRequestBody_customAttributes_value

@dataclass
class IssuesPostRequestBody_customAttributes(Parsable):
    # The unique identifier of the custom attribute.
    attribute_definition_id: Optional[UUID] = None
    # Custom attribute value. Possible value types: ``string``, ``number``, ``null``.
    value: Optional[IssuesPostRequestBody_customAttributes_value] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> IssuesPostRequestBody_customAttributes:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: IssuesPostRequestBody_customAttributes
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return IssuesPostRequestBody_customAttributes()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .issues_post_request_body_custom_attributes_value import IssuesPostRequestBody_customAttributes_value

        from .issues_post_request_body_custom_attributes_value import IssuesPostRequestBody_customAttributes_value

        fields: dict[str, Callable[[Any], None]] = {
            "attributeDefinitionId": lambda n : setattr(self, 'attribute_definition_id', n.get_uuid_value()),
            "value": lambda n : setattr(self, 'value', n.get_object_value(IssuesPostRequestBody_customAttributes_value)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_uuid_value("attributeDefinitionId", self.attribute_definition_id)
        writer.write_object_value("value", self.value)
    

