from enum import Enum

class ViewsGetResponse_modelSetViewVersions_documentVersions_documentStatus(str, Enum):
    Succeeded = "Succeeded",
    Failed = "Failed",
    Running = "Running",
    Skipped = "Skipped",

