from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class SheetsGetResponse_results_viewable(Parsable):
    """
    Information about the sheet relevant for loading the sheet to the Viewer. See `Add Viewer to an HTML Page <https://forge.autodesk.com/en/docs/viewer/v7/developers_guide/viewer_basics/>`_ for more information.
    """
    # The GUID of the viewable resources.When loading the sheet to the viewer, this GUID should be used to find the related geometry node of the sheet.
    guid: Optional[str] = None
    # The URN of the viewable resources. Multiple sheets created by the same original file may share the same viewable URN.When loading the sheet to the viewer, this URN should be used as the documentId to get the manifest.
    urn: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> SheetsGetResponse_results_viewable:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: SheetsGetResponse_results_viewable
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return SheetsGetResponse_results_viewable()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "guid": lambda n : setattr(self, 'guid', n.get_str_value()),
            "urn": lambda n : setattr(self, 'urn', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("guid", self.guid)
        writer.write_str_value("urn", self.urn)
    

