from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Optional, TYPE_CHECKING, Union
from uuid import UUID
from warnings import warn

if TYPE_CHECKING:
    from .item.with_package_item_request_builder import WithPackageItemRequestBuilder
    from .packages_get_response import PackagesGetResponse
    from .packages_post_request_body import PackagesPostRequestBody
    from .packages_post_response import PackagesPostResponse

class PackagesRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /construction/takeoff/v1/projects/{projectId}/packages
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new PackagesRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/construction/takeoff/v1/projects/{projectId}/packages{?limit*,offset*}", path_parameters)
    
    def by_package_id(self,package_id: UUID) -> WithPackageItemRequestBuilder:
        """
        Gets an item from the Autodesk.ACC.construction.takeoff.v1.projects.item.packages.item collection
        param package_id: The takeoff package ID.To find the ID, call `GET packages </en/docs/acc/v1/reference/http/takeoff-projects-project_id-packages-GET/>`_.
        Returns: WithPackageItemRequestBuilder
        """
        if package_id is None:
            raise TypeError("package_id cannot be null.")
        from .item.with_package_item_request_builder import WithPackageItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["packageId"] = package_id
        return WithPackageItemRequestBuilder(self.request_adapter, url_tpl_params)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[PackagesRequestBuilderGetQueryParameters]] = None) -> Optional[PackagesGetResponse]:
        """
        Retrieves the takeoff packages for a project.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[PackagesGetResponse]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .packages_get_response import PackagesGetResponse

        return await self.request_adapter.send_async(request_info, PackagesGetResponse, None)
    
    async def post(self,body: PackagesPostRequestBody, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> Optional[PackagesPostResponse]:
        """
        Creates a takeoff package for a project.
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[PackagesPostResponse]
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = self.to_post_request_information(
            body, request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .packages_post_response import PackagesPostResponse

        return await self.request_adapter.send_async(request_info, PackagesPostResponse, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[PackagesRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        Retrieves the takeoff packages for a project.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def to_post_request_information(self,body: PackagesPostRequestBody, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        Creates a takeoff package for a project.
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = RequestInformation(Method.POST, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        request_info.set_content_from_parsable(self.request_adapter, "application/json", body)
        return request_info
    
    def with_url(self,raw_url: str) -> PackagesRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: PackagesRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return PackagesRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class PackagesRequestBuilderGetQueryParameters():
        """
        Retrieves the takeoff packages for a project.
        """
        # The maximum number of packages per page.Acceptable values: ``1-200``.Default value: ``200``.
        limit: Optional[int] = None

        # The package index from which the pagination starts. This is zero-based.
        offset: Optional[int] = None

    
    @dataclass
    class PackagesRequestBuilderGetRequestConfiguration(RequestConfiguration[PackagesRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    
    @dataclass
    class PackagesRequestBuilderPostRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    

