from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .classifications_import_post_request_body_classifications import ClassificationsImportPostRequestBody_classifications

@dataclass
class ClassificationsImportPostRequestBody(Parsable):
    # The classification system name.Max length: 200
    classification_system_name: Optional[str] = None
    # The classification hierarchy.The classification hierarchy is configured as a JSON array in the payload, created from a spreadsheet file.Max size: ``30000``.For more details, see the `ACC Configure Takeoff Settings <https://help.autodesk.com/view/TAKEOFF/ENU/?guid=Configure_Takeoff_Settings>`_ help documentation.
    classifications: Optional[list[ClassificationsImportPostRequestBody_classifications]] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ClassificationsImportPostRequestBody:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ClassificationsImportPostRequestBody
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ClassificationsImportPostRequestBody()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .classifications_import_post_request_body_classifications import ClassificationsImportPostRequestBody_classifications

        from .classifications_import_post_request_body_classifications import ClassificationsImportPostRequestBody_classifications

        fields: dict[str, Callable[[Any], None]] = {
            "classificationSystemName": lambda n : setattr(self, 'classification_system_name', n.get_str_value()),
            "classifications": lambda n : setattr(self, 'classifications', n.get_collection_of_object_values(ClassificationsImportPostRequestBody_classifications)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("classificationSystemName", self.classification_system_name)
        writer.write_collection_of_object_values("classifications", self.classifications)
    

