from enum import Enum

class GetAssociationTypeQueryParameterType(str, Enum):
    Contract = "Contract",
    Payment = "Payment",
    BudgetPayment = "BudgetPayment",
    CostPayment = "CostPayment",
    Expense = "Expense",
    PCO = "PCO",
    OCO = "OCO",
    SCO = "SCO",
    RCO = "RCO",
    RFQ = "RFQ",
    DistributionItem = "DistributionItem",

