from __future__ import annotations
from collections.abc import Callable
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .item.with_version_item_request_builder import WithVersionItemRequestBuilder

class VersionRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /construction/autospecs/v1/projects/{projectId}/version
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new VersionRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/construction/autospecs/v1/projects/{projectId}/version", path_parameters)
    
    def by_version_id(self,version_id: str) -> WithVersionItemRequestBuilder:
        """
        Gets an item from the Autodesk.ACC.construction.autospecs.v1.projects.item.version.item collection
        param version_id: The AutoSpecs version ID of the project. For information about how to find the version ID, see the first few steps of the `Retrieve Submittal Log </en/docs/acc/v1/tutorials/autospecs/upload-document/>`_ tutorial.
        Returns: WithVersionItemRequestBuilder
        """
        if version_id is None:
            raise TypeError("version_id cannot be null.")
        from .item.with_version_item_request_builder import WithVersionItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["versionId"] = version_id
        return WithVersionItemRequestBuilder(self.request_adapter, url_tpl_params)
    

