from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from .expenses_get_response import ExpensesGetResponse
    from .expenses_post_request_body import ExpensesPostRequestBody
    from .expenses_post_response import ExpensesPostResponse
    from .item.expense_item_request_builder import ExpenseItemRequestBuilder

class ExpensesRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /cost/v1/containers/{containerId}/expenses
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new ExpensesRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/cost/v1/containers/{containerId}/expenses{?filter%5BbudgetPaymentId%5D*,filter%5BcreatedAt%5D*,filter%5BexternalId%5D*,filter%5BexternalSystem%5D*,filter%5Bid%5D*,filter%5BlastModifiedSince%5D*,filter%5BmainContractId%5D*,filter%5Bnumber%5D*,filter%5Bstatus%5D*,include*,limit*,offset*,sort*}", path_parameters)
    
    def by_expense_id(self,expense_id: str) -> ExpenseItemRequestBuilder:
        """
        Gets an item from the Autodesk.ACC.cost.v1.containers.item.expenses.item collection
        param expense_id: The object ID of the expense. You can obtain this ID from the response to the `POST expenses </en/docs/bim360/v1/reference/http/cost-expenses-POST/>`_ or `GET expenses </en/docs/bim360/v1/reference/http/cost-expenses-GET/>`_ endpoint.
        Returns: ExpenseItemRequestBuilder
        """
        if expense_id is None:
            raise TypeError("expense_id cannot be null.")
        from .item.expense_item_request_builder import ExpenseItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["expense%2Did"] = expense_id
        return ExpenseItemRequestBuilder(self.request_adapter, url_tpl_params)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[ExpensesRequestBuilderGetQueryParameters]] = None) -> Optional[ExpensesGetResponse]:
        """
        Retrieves the requested set of expenses in the specified project.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[ExpensesGetResponse]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .expenses_get_response import ExpensesGetResponse

        return await self.request_adapter.send_async(request_info, ExpensesGetResponse, None)
    
    async def post(self,body: ExpensesPostRequestBody, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> Optional[ExpensesPostResponse]:
        """
        Creates an expense in the given project.
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[ExpensesPostResponse]
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = self.to_post_request_information(
            body, request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .expenses_post_response import ExpensesPostResponse

        return await self.request_adapter.send_async(request_info, ExpensesPostResponse, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[ExpensesRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        Retrieves the requested set of expenses in the specified project.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def to_post_request_information(self,body: ExpensesPostRequestBody, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        Creates an expense in the given project.
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = RequestInformation(Method.POST, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        request_info.set_content_from_parsable(self.request_adapter, "application/json", body)
        return request_info
    
    def with_url(self,raw_url: str) -> ExpensesRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: ExpensesRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return ExpensesRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class ExpensesRequestBuilderGetQueryParameters():
        """
        Retrieves the requested set of expenses in the specified project.
        """
        def get_query_parameter(self,original_name: str) -> str:
            """
            Maps the query parameters names to their encoded names for the URI template parsing.
            param original_name: The original query parameter name in the class.
            Returns: str
            """
            if original_name is None:
                raise TypeError("original_name cannot be null.")
            if original_name == "filterbudget_payment_id":
                return "filter%5BbudgetPaymentId%5D"
            if original_name == "filtercreated_at":
                return "filter%5BcreatedAt%5D"
            if original_name == "filterexternal_id":
                return "filter%5BexternalId%5D"
            if original_name == "filterexternal_system":
                return "filter%5BexternalSystem%5D"
            if original_name == "filterid":
                return "filter%5Bid%5D"
            if original_name == "filterlast_modified_since":
                return "filter%5BlastModifiedSince%5D"
            if original_name == "filtermain_contract_id":
                return "filter%5BmainContractId%5D"
            if original_name == "filternumber":
                return "filter%5Bnumber%5D"
            if original_name == "filterstatus":
                return "filter%5Bstatus%5D"
            if original_name == "include":
                return "include"
            if original_name == "limit":
                return "limit"
            if original_name == "offset":
                return "offset"
            if original_name == "sort":
                return "sort"
            return original_name
        
        # Returns only the payments associated with the budget payments (used to query the related cost payments or expenses) that are identified on this list of IDs. Separate multiple IDs with commas; for example, ``filter[budgetPaymentId]=id1,id2``.
        filterbudget_payment_id: Optional[list[str]] = None

        # Filter data by its create date. This may be an ISO 8601 date string or a range. Ranges can be **lowerValue..upperValue**, **lowerValue..** or **..upperValue**. The range tests are always inclusive of their endpoints.
        filtercreated_at: Optional[str] = None

        # The ID of the item in the external ERP system. Use this ID to track or look up data in an integrated ERP system. For example, ``filter[externalId]=id1,id2``.
        filterexternal_id: Optional[list[str]] = None

        # The name of the external ERP system. Use this name to identify or search within the integrated system. For example, ``filter[externalSystem]=Sage300``.Max length: 255
        filterexternal_system: Optional[str] = None

        # Returns only the items that are identified by the provided list of item IDs. Separate multiple IDs with commas. For example, ``filter[id]=id1,id2``.
        filterid: Optional[list[str]] = None

        # Returns only items that were modified since the specified date and time, in ISO 8601 format. For example, ``filter[lastModifiedSince]=2020-03-01T13:00:00Z``.
        filterlast_modified_since: Optional[str] = None

        # The Main Contract ID. Separate multiple IDs with commas. For example, ``filter[mainContractId]=id1,id2``, or filter these items that are not linked to any main contract  ``filter[mainContractId]=blank``.
        filtermain_contract_id: Optional[list[str]] = None

        # Returns only the items that are identified by the provided list of auto-generated sequence numbers. Separate multiple numbers with commas; for example, ``filter[number]=0001,0002``.
        filternumber: Optional[list[str]] = None

        # Returns only contracts with the specified statuses. Separate multiple values with commas. For example, ``filter[status]=draft,pending``. Possible values:``draft``, ``pending``, ``submitted``, ``revise``, ``sent``, ``signed``, ``executed``, ``closed``, ``inReview``.
        filterstatus: Optional[list[str]] = None

        # A list of the nested expense resources to include in the response with the expenses. For example, ``include=expenseItems`` returns the expense items related to each expense. ``include=attributes`` will return custom attributes which represents the ``properties`` in the response.Possible values: ``expenseItems``, ``mainContract``, ``attributes``, ``externalRelationship``, ``paymentReferences``.
        include: Optional[list[str]] = None

        # The maximum number of records returned per page. Default: ``100``. A page may contain fewer records than the limit if there are fewer matching items or if it is the last page of results.
        limit: Optional[int] = None

        # The number of records to skip before returning results. Used together with ``limit`` to paginate through results, where ``offset`` specifies the starting point and ``limit`` specifies the number of records to return.
        offset: Optional[int] = None

        # Defines the sort order for the results. Each attribute can be sorted in ``asc`` (default) or ``desc`` order. For example, ``sort=name desc`` sorts the results by name in descending order.
        sort: Optional[str] = None

    
    @dataclass
    class ExpensesRequestBuilderGetRequestConfiguration(RequestConfiguration[ExpensesRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    
    @dataclass
    class ExpensesRequestBuilderPostRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    

