from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class ExportsPostRequestBody_options_photoMarkups(Parsable):
    """
    The list of types of photo markups to export.
    """
    # ``true``: published photo markups will be included in the exported sheets.``false``: (default) published photo markups will not be included in the exported sheets.
    include_published_markups: Optional[bool] = None
    # ``true``: include photo markups in the exported sheets that are visible only to their creators or assignees.``false``: (default) export sheets without including unpublished photo markups.
    include_unpublished_markups: Optional[bool] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ExportsPostRequestBody_options_photoMarkups:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ExportsPostRequestBody_options_photoMarkups
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ExportsPostRequestBody_options_photoMarkups()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "includePublishedMarkups": lambda n : setattr(self, 'include_published_markups', n.get_bool_value()),
            "includeUnpublishedMarkups": lambda n : setattr(self, 'include_unpublished_markups', n.get_bool_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_bool_value("includePublishedMarkups", self.include_published_markups)
        writer.write_bool_value("includeUnpublishedMarkups", self.include_unpublished_markups)
    

