from enum import Enum

class WithFormPatchRequestBody_status(str, Enum):
    Draft = "draft",
    Discarded = "discarded",
    Submitted = "submitted",
    Archived = "archived",
    In_review = "in_review",

