from enum import Enum

class PaymentItemsGetResponse_results_associationType(str, Enum):
    SCO = "SCO",
    OCO = "OCO",
    SOV = "SOV",
    CostItem = "CostItem",
    SubCostItem = "SubCostItem",
    MaterialsOnSite = "MaterialsOnSite",

