from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Optional, TYPE_CHECKING, Union
from uuid import UUID
from warnings import warn

if TYPE_CHECKING:
    from .custom_attributes_get_response import CustomAttributesGetResponse
    from .item.with_custom_attribute_item_request_builder import WithCustomAttributeItemRequestBuilder

class CustomAttributesRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /construction/assets/v1/projects/{projectId}/categories/{categoryId}/custom-attributes
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new CustomAttributesRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/construction/assets/v1/projects/{projectId}/categories/{categoryId}/custom-attributes{?includeInherited*}", path_parameters)
    
    def by_custom_attribute_id(self,custom_attribute_id: UUID) -> WithCustomAttributeItemRequestBuilder:
        """
        Gets an item from the Autodesk.ACC.construction.assets.v1.projects.item.categories.item.customAttributes.item collection
        param custom_attribute_id: Asset custom attribute ID
        Returns: WithCustomAttributeItemRequestBuilder
        """
        if custom_attribute_id is None:
            raise TypeError("custom_attribute_id cannot be null.")
        from .item.with_custom_attribute_item_request_builder import WithCustomAttributeItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["customAttributeId"] = custom_attribute_id
        return WithCustomAttributeItemRequestBuilder(self.request_adapter, url_tpl_params)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[CustomAttributesRequestBuilderGetQueryParameters]] = None) -> Optional[CustomAttributesGetResponse]:
        """
        GET categories/:categoryId/custom-attributes
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[CustomAttributesGetResponse]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .custom_attributes_get_response import CustomAttributesGetResponse

        return await self.request_adapter.send_async(request_info, CustomAttributesGetResponse, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[CustomAttributesRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        GET categories/:categoryId/custom-attributes
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def with_url(self,raw_url: str) -> CustomAttributesRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: CustomAttributesRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return CustomAttributesRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class CustomAttributesRequestBuilderGetQueryParameters():
        """
        GET categories/:categoryId/custom-attributes
        """
        def get_query_parameter(self,original_name: str) -> str:
            """
            Maps the query parameters names to their encoded names for the URI template parsing.
            param original_name: The original query parameter name in the class.
            Returns: str
            """
            if original_name is None:
                raise TypeError("original_name cannot be null.")
            if original_name == "include_inherited":
                return "includeInherited"
            return original_name
        
        # Specifies whether or not to return custom attributes that were inherited from the specified category'sparent category. If ``true``, then it returns inherited custom attributes. If ``false``, then it returns only customattributes explicitly assigned to the specified category. Default is ``false``.
        include_inherited: Optional[bool] = None

    
    @dataclass
    class CustomAttributesRequestBuilderGetRequestConfiguration(RequestConfiguration[CustomAttributesRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    

