from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from .issues.issues_request_builder import IssuesRequestBuilder
    from .jobs.jobs_request_builder import JobsRequestBuilder
    from .screenshots.screenshots_request_builder import ScreenshotsRequestBuilder
    from .versions.versions_request_builder import VersionsRequestBuilder
    from .versions_disable.versions_disable_request_builder import VersionsDisableRequestBuilder
    from .versions_enable.versions_enable_request_builder import VersionsEnableRequestBuilder
    from .views.views_request_builder import ViewsRequestBuilder
    from .views_lineages.views_lineages_request_builder import ViewsLineagesRequestBuilder
    from .with_model_set_get_response import WithModelSetGetResponse
    from .with_model_set_patch_request_body import WithModelSetPatchRequestBody
    from .with_model_set_patch_response import WithModelSetPatchResponse

class WithModelSetItemRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /bim360/modelset/v3/containers/{containerId}/modelsets/{modelSetId}
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new WithModelSetItemRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/bim360/modelset/v3/containers/{containerId}/modelsets/{modelSetId}", path_parameters)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> Optional[WithModelSetGetResponse]:
        """
        Returns the requested model set object.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[WithModelSetGetResponse]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .with_model_set_get_response import WithModelSetGetResponse

        return await self.request_adapter.send_async(request_info, WithModelSetGetResponse, None)
    
    async def patch(self,body: WithModelSetPatchRequestBody, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> Optional[WithModelSetPatchResponse]:
        """
        If no property changes are supplied, an error is returned.
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[WithModelSetPatchResponse]
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = self.to_patch_request_information(
            body, request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .with_model_set_patch_response import WithModelSetPatchResponse

        return await self.request_adapter.send_async(request_info, WithModelSetPatchResponse, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        Returns the requested model set object.
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def to_patch_request_information(self,body: WithModelSetPatchRequestBody, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        If no property changes are supplied, an error is returned.
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = RequestInformation(Method.PATCH, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        request_info.set_content_from_parsable(self.request_adapter, "application/json", body)
        return request_info
    
    def with_url(self,raw_url: str) -> WithModelSetItemRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: WithModelSetItemRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return WithModelSetItemRequestBuilder(self.request_adapter, raw_url)
    
    @property
    def issues(self) -> IssuesRequestBuilder:
        """
        The issues property
        """
        from .issues.issues_request_builder import IssuesRequestBuilder

        return IssuesRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def jobs(self) -> JobsRequestBuilder:
        """
        The jobs property
        """
        from .jobs.jobs_request_builder import JobsRequestBuilder

        return JobsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def screenshots(self) -> ScreenshotsRequestBuilder:
        """
        The screenshots property
        """
        from .screenshots.screenshots_request_builder import ScreenshotsRequestBuilder

        return ScreenshotsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def versions(self) -> VersionsRequestBuilder:
        """
        The versions property
        """
        from .versions.versions_request_builder import VersionsRequestBuilder

        return VersionsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def versions_disable(self) -> VersionsDisableRequestBuilder:
        """
        The versionsDisable property
        """
        from .versions_disable.versions_disable_request_builder import VersionsDisableRequestBuilder

        return VersionsDisableRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def versions_enable(self) -> VersionsEnableRequestBuilder:
        """
        The versionsEnable property
        """
        from .versions_enable.versions_enable_request_builder import VersionsEnableRequestBuilder

        return VersionsEnableRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def views(self) -> ViewsRequestBuilder:
        """
        The views property
        """
        from .views.views_request_builder import ViewsRequestBuilder

        return ViewsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def views_lineages(self) -> ViewsLineagesRequestBuilder:
        """
        The viewsLineages property
        """
        from .views_lineages.views_lineages_request_builder import ViewsLineagesRequestBuilder

        return ViewsLineagesRequestBuilder(self.request_adapter, self.path_parameters)
    
    @dataclass
    class WithModelSetItemRequestBuilderGetRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    
    @dataclass
    class WithModelSetItemRequestBuilderPatchRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    

