from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .uploads_post_request_body_files import UploadsPostRequestBody_files

@dataclass
class UploadsPostRequestBody(Parsable):
    # The list of files to be processed by the upload.
    files: Optional[list[UploadsPostRequestBody_files]] = None
    # The ID of the version set you want to upload the sheets to.To create a new version set, call `POST version-sets </en/docs/acc/v1/reference/http/sheets-version-sets-POST/>`_.To find the ID of an existing version set, call `GET version-sets </en/docs/acc/v1/reference/http/sheets-version-sets-GET/>`_.
    version_set_id: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> UploadsPostRequestBody:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: UploadsPostRequestBody
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return UploadsPostRequestBody()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .uploads_post_request_body_files import UploadsPostRequestBody_files

        from .uploads_post_request_body_files import UploadsPostRequestBody_files

        fields: dict[str, Callable[[Any], None]] = {
            "files": lambda n : setattr(self, 'files', n.get_collection_of_object_values(UploadsPostRequestBody_files)),
            "versionSetId": lambda n : setattr(self, 'version_set_id', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_collection_of_object_values("files", self.files)
        writer.write_str_value("versionSetId", self.version_set_id)
    

