from enum import Enum

class GetFilterAssociationTypeQueryParameterType(str, Enum):
    Contract = "Contract",
    MainContract = "MainContract",
    FilterAssociationTypeContract = "filter[associationType]=Contract",

