from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union
from uuid import UUID

if TYPE_CHECKING:
    from .property_values_batch_update_post_request_body_association_type import PropertyValuesBatchUpdatePostRequestBody_associationType

@dataclass
class PropertyValuesBatchUpdatePostRequestBody(Parsable):
    # The object ID of the item associated with the actions, such as a budget, contract, or cost item.
    association_id: Optional[UUID] = None
    # The type of item to which it is associated.Possible values: ``Budget``, ``Contract``, ``ScheduleOfValue``, ``FormInstance``, ``CostItem``, ``Payment``, ``MainContract``, ``BudgetPayment``, ``Expense``, ``CostPayment``, ``ExpenseItem``, ``PaymentItem``, ``OCO``, ``RCO``, ``SCO``, ``PCO``, ``RFQ``, ``DistributionItem``, ``BudgetTransfer``, ``Fee``
    association_type: Optional[PropertyValuesBatchUpdatePostRequestBody_associationType] = None
    # ID of the custom attribute definition.
    property_definition_id: Optional[UUID] = None
    # Value of the custom attribute associated to an item.
    value: Optional[float] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> PropertyValuesBatchUpdatePostRequestBody:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: PropertyValuesBatchUpdatePostRequestBody
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return PropertyValuesBatchUpdatePostRequestBody()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .property_values_batch_update_post_request_body_association_type import PropertyValuesBatchUpdatePostRequestBody_associationType

        from .property_values_batch_update_post_request_body_association_type import PropertyValuesBatchUpdatePostRequestBody_associationType

        fields: dict[str, Callable[[Any], None]] = {
            "associationId": lambda n : setattr(self, 'association_id', n.get_uuid_value()),
            "associationType": lambda n : setattr(self, 'association_type', n.get_enum_value(PropertyValuesBatchUpdatePostRequestBody_associationType)),
            "propertyDefinitionId": lambda n : setattr(self, 'property_definition_id', n.get_uuid_value()),
            "value": lambda n : setattr(self, 'value', n.get_float_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_uuid_value("associationId", self.association_id)
        writer.write_enum_value("associationType", self.association_type)
        writer.write_uuid_value("propertyDefinitionId", self.property_definition_id)
        writer.write_float_value("value", self.value)
    

