from enum import Enum

class WithIssueGetResponse_status(str, Enum):
    Draft = "draft",
    Open = "open",
    Pending = "pending",
    In_progress = "in_progress",
    Completed = "completed",
    In_review = "in_review",
    Not_approved = "not_approved",
    In_dispute = "in_dispute",
    Closed = "closed",

