from enum import Enum

class WithItemIdTransitionPostRequestBody_stateId(str, Enum):
    PermittedActions = "permittedActions",
    Draft = "draft",
    Rev = "rev",
    Sbc = "sbc",
    Mgr = "mgr",
    Void = "void",

