from __future__ import annotations
from collections.abc import Callable
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .requirements.requirements_request_builder import RequirementsRequestBuilder
    from .smartregister.smartregister_request_builder import SmartregisterRequestBuilder
    from .submittals_summary.submittals_summary_request_builder import SubmittalsSummaryRequestBuilder

class WithVersionItemRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /construction/autospecs/v1/projects/{projectId}/version/{versionId}
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new WithVersionItemRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/construction/autospecs/v1/projects/{projectId}/version/{versionId}", path_parameters)
    
    @property
    def requirements(self) -> RequirementsRequestBuilder:
        """
        The requirements property
        """
        from .requirements.requirements_request_builder import RequirementsRequestBuilder

        return RequirementsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def smartregister(self) -> SmartregisterRequestBuilder:
        """
        The smartregister property
        """
        from .smartregister.smartregister_request_builder import SmartregisterRequestBuilder

        return SmartregisterRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def submittals_summary(self) -> SubmittalsSummaryRequestBuilder:
        """
        The submittalsSummary property
        """
        from .submittals_summary.submittals_summary_request_builder import SubmittalsSummaryRequestBuilder

        return SubmittalsSummaryRequestBuilder(self.request_adapter, self.path_parameters)
    

