from __future__ import annotations
from collections.abc import Callable
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .attributes.attributes_request_builder import AttributesRequestBuilder
    from .rfis.rfis_request_builder import RfisRequestBuilder
    from .rfi_types.rfi_types_request_builder import RfiTypesRequestBuilder
    from .search_rfis.search_rfis_request_builder import SearchRfisRequestBuilder
    from .users.users_request_builder import UsersRequestBuilder
    from .workflow.workflow_request_builder import WorkflowRequestBuilder

class WithProjectItemRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /construction/rfis/v3/projects/{projectId}
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new WithProjectItemRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/construction/rfis/v3/projects/{projectId}", path_parameters)
    
    @property
    def attributes(self) -> AttributesRequestBuilder:
        """
        The attributes property
        """
        from .attributes.attributes_request_builder import AttributesRequestBuilder

        return AttributesRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def rfi_types(self) -> RfiTypesRequestBuilder:
        """
        The rfiTypes property
        """
        from .rfi_types.rfi_types_request_builder import RfiTypesRequestBuilder

        return RfiTypesRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def rfis(self) -> RfisRequestBuilder:
        """
        The rfis property
        """
        from .rfis.rfis_request_builder import RfisRequestBuilder

        return RfisRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def search_rfis(self) -> SearchRfisRequestBuilder:
        """
        The searchRfis property
        """
        from .search_rfis.search_rfis_request_builder import SearchRfisRequestBuilder

        return SearchRfisRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def users(self) -> UsersRequestBuilder:
        """
        The users property
        """
        from .users.users_request_builder import UsersRequestBuilder

        return UsersRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def workflow(self) -> WorkflowRequestBuilder:
        """
        The workflow property
        """
        from .workflow.workflow_request_builder import WorkflowRequestBuilder

        return WorkflowRequestBuilder(self.request_adapter, self.path_parameters)
    

