from enum import Enum

class GetSortQueryParameterType(str, Enum):
    Asc = "asc",
    Desc = "desc",
    Name = "name",
    Description = "description",
    UpdatedAt = "updatedAt",
    ApprovalStatus = "approvalStatus",
    Version = "version",
    SortNameDesc = "sort=name desc",

