from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .relationships_writable_get_response_entity_types import RelationshipsWritableGetResponse_entityTypes

@dataclass
class RelationshipsWritableGetResponse(Parsable):
    # The domain to which the entity types belong.For example: ``autodesk-bim360-asset``To learn more about domains and entities, see the `Relationship Service Field Guide </en/docs/bim360/v1/overview/field-guide/relationships>`_.
    domain: Optional[str] = None
    # The list of entity types in the domain.
    entity_types: Optional[list[RelationshipsWritableGetResponse_entityTypes]] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> RelationshipsWritableGetResponse:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: RelationshipsWritableGetResponse
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return RelationshipsWritableGetResponse()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .relationships_writable_get_response_entity_types import RelationshipsWritableGetResponse_entityTypes

        from .relationships_writable_get_response_entity_types import RelationshipsWritableGetResponse_entityTypes

        fields: dict[str, Callable[[Any], None]] = {
            "domain": lambda n : setattr(self, 'domain', n.get_str_value()),
            "entityTypes": lambda n : setattr(self, 'entity_types', n.get_collection_of_object_values(RelationshipsWritableGetResponse_entityTypes)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("domain", self.domain)
        writer.write_collection_of_object_values("entityTypes", self.entity_types)
    

