from enum import Enum

class SmartregisterGetResponse_targetGroup(str, Enum):
    ACTIONANDINFORMATIONAL = "ACTION AND INFORMATIONAL",
    CloseoutSubmittals = "Closeout Submittals",
    DIVISION01REQUIREMENTS = "DIVISION 01 REQUIREMENTS",
    FieldQualityControl = "Field Quality Control",
    Mockups = "Mockups",
    QUALITYASSURANCE = "QUALITY ASSURANCE",
    TESTSANDINSPECTIONS = "TESTS AND INSPECTIONS",

